Class: Pago::V2026_04::Models::BenefitFeatureFlagSubscriber
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ id: "id", created_at: "created_at", modified_at: "modified_at", type: "type", description: "description", selectable: "selectable", deletable: "deletable", is_deleted: "is_deleted", organization_id: "organization_id", organization: "organization", properties: "properties" }.freeze
- REQUIRED_KEYS =
["id", "created_at", "modified_at", "type", "description", "selectable", "deletable", "is_deleted", "organization_id", "organization", "properties"].freeze
Instance Attribute Summary collapse
-
#created_at ⇒ String
readonly
Creation timestamp of the object.
-
#deletable ⇒ Boolean
readonly
Whether the benefit is deletable.
-
#description ⇒ String
readonly
The description of the benefit.
-
#id ⇒ String
readonly
The ID of the benefit.
-
#is_deleted ⇒ Boolean
readonly
Whether the benefit is deleted.
-
#modified_at ⇒ String?
readonly
Last modification timestamp of the object.
- #organization ⇒ Models::BenefitSubscriberOrganization readonly
-
#organization_id ⇒ String
readonly
The ID of the organization owning the benefit.
- #properties ⇒ Models::BenefitFeatureFlagSubscriberProperties readonly
-
#selectable ⇒ Boolean
readonly
Whether the benefit is selectable when creating a product.
- #type ⇒ String readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, organization:, properties:) ⇒ BenefitFeatureFlagSubscriber
constructor
A new instance of BenefitFeatureFlagSubscriber.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, organization:, properties:) ⇒ BenefitFeatureFlagSubscriber
Returns a new instance of BenefitFeatureFlagSubscriber.
3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 3939 3940 3941 3942 3943 3944 3945 3946 3947 3948 3949 |
# File 'lib/pago/v2026_04/models.rb', line 3924 def initialize( id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, organization:, properties: ) super() assign(:id, id) assign(:created_at, created_at) assign(:modified_at, modified_at) assign(:type, type) assign(:description, description) assign(:selectable, selectable) assign(:deletable, deletable) assign(:is_deleted, is_deleted) assign(:organization_id, organization_id) assign(:organization, organization) assign(:properties, properties) end |
Instance Attribute Details
#created_at ⇒ String (readonly)
Creation timestamp of the object.
3889 3890 3891 |
# File 'lib/pago/v2026_04/models.rb', line 3889 def created_at @created_at end |
#deletable ⇒ Boolean (readonly)
Whether the benefit is deletable.
3908 3909 3910 |
# File 'lib/pago/v2026_04/models.rb', line 3908 def deletable @deletable end |
#description ⇒ String (readonly)
The description of the benefit.
3900 3901 3902 |
# File 'lib/pago/v2026_04/models.rb', line 3900 def description @description end |
#id ⇒ String (readonly)
The ID of the benefit.
3885 3886 3887 |
# File 'lib/pago/v2026_04/models.rb', line 3885 def id @id end |
#is_deleted ⇒ Boolean (readonly)
Whether the benefit is deleted.
3912 3913 3914 |
# File 'lib/pago/v2026_04/models.rb', line 3912 def is_deleted @is_deleted end |
#modified_at ⇒ String? (readonly)
Last modification timestamp of the object.
3893 3894 3895 |
# File 'lib/pago/v2026_04/models.rb', line 3893 def modified_at @modified_at end |
#organization ⇒ Models::BenefitSubscriberOrganization (readonly)
3919 3920 3921 |
# File 'lib/pago/v2026_04/models.rb', line 3919 def organization @organization end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the benefit.
3916 3917 3918 |
# File 'lib/pago/v2026_04/models.rb', line 3916 def organization_id @organization_id end |
#properties ⇒ Models::BenefitFeatureFlagSubscriberProperties (readonly)
3922 3923 3924 |
# File 'lib/pago/v2026_04/models.rb', line 3922 def properties @properties end |
#selectable ⇒ Boolean (readonly)
Whether the benefit is selectable when creating a product.
3904 3905 3906 |
# File 'lib/pago/v2026_04/models.rb', line 3904 def selectable @selectable end |
#type ⇒ String (readonly)
3896 3897 3898 |
# File 'lib/pago/v2026_04/models.rb', line 3896 def type @type end |
Class Method Details
.from_json(data) ⇒ BenefitFeatureFlagSubscriber?
3953 3954 3955 3956 3957 3958 3959 3960 3961 3962 3963 3964 3965 3966 3967 3968 3969 3970 3971 3972 3973 3974 |
# File 'lib/pago/v2026_04/models.rb', line 3953 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), created_at: (data.key?("created_at") ? data["created_at"] : ::Pago::UNSET), modified_at: (data.key?("modified_at") ? data["modified_at"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), description: (data.key?("description") ? data["description"] : ::Pago::UNSET), selectable: (data.key?("selectable") ? data["selectable"] : ::Pago::UNSET), deletable: (data.key?("deletable") ? data["deletable"] : ::Pago::UNSET), is_deleted: (data.key?("is_deleted") ? data["is_deleted"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), organization: (data.key?("organization") ? Models::BenefitSubscriberOrganization.from_json(data["organization"]) : ::Pago::UNSET), properties: (data.key?("properties") ? Models::BenefitFeatureFlagSubscriberProperties.from_json(data["properties"]) : ::Pago::UNSET) ), data ) end |