Class: Pago::V2026_04::Models::BenefitLicenseKeys
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ id: "id", created_at: "created_at", modified_at: "modified_at", type: "type", description: "description", selectable: "selectable", deletable: "deletable", is_deleted: "is_deleted", organization_id: "organization_id", metadata: "metadata", visibility: "visibility", properties: "properties", visibility_configurable: "visibility_configurable" }.freeze
- REQUIRED_KEYS =
["id", "created_at", "modified_at", "type", "description", "selectable", "deletable", "is_deleted", "organization_id", "metadata", "visibility", "properties", "visibility_configurable"].freeze
Instance Attribute Summary collapse
-
#created_at ⇒ String
readonly
Creation timestamp of the object.
-
#deletable ⇒ Boolean
readonly
Whether the benefit is deletable.
-
#description ⇒ String
readonly
The description of the benefit.
-
#id ⇒ String
readonly
The ID of the benefit.
-
#is_deleted ⇒ Boolean
readonly
Whether the benefit is deleted.
- #metadata ⇒ Hash{String => String, Integer, Float, Boolean} readonly
-
#modified_at ⇒ String?
readonly
Last modification timestamp of the object.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the benefit.
- #properties ⇒ Models::BenefitLicenseKeysProperties readonly
-
#selectable ⇒ Boolean
readonly
Whether the benefit is selectable when creating a product.
- #type ⇒ String readonly
- #visibility ⇒ String readonly
- #visibility_configurable ⇒ Boolean readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, metadata:, visibility:, properties:, visibility_configurable:) ⇒ BenefitLicenseKeys
constructor
A new instance of BenefitLicenseKeys.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, metadata:, visibility:, properties:, visibility_configurable:) ⇒ BenefitLicenseKeys
Returns a new instance of BenefitLicenseKeys.
6827 6828 6829 6830 6831 6832 6833 6834 6835 6836 6837 6838 6839 6840 6841 6842 6843 6844 6845 6846 6847 6848 6849 6850 6851 6852 6853 6854 6855 6856 |
# File 'lib/pago/v2026_04/models.rb', line 6827 def initialize( id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, metadata:, visibility:, properties:, visibility_configurable: ) super() assign(:id, id) assign(:created_at, created_at) assign(:modified_at, modified_at) assign(:type, type) assign(:description, description) assign(:selectable, selectable) assign(:deletable, deletable) assign(:is_deleted, is_deleted) assign(:organization_id, organization_id) assign(:metadata, ) assign(:visibility, visibility) assign(:properties, properties) assign(:visibility_configurable, visibility_configurable) end |
Instance Attribute Details
#created_at ⇒ String (readonly)
Creation timestamp of the object.
6786 6787 6788 |
# File 'lib/pago/v2026_04/models.rb', line 6786 def created_at @created_at end |
#deletable ⇒ Boolean (readonly)
Whether the benefit is deletable.
6805 6806 6807 |
# File 'lib/pago/v2026_04/models.rb', line 6805 def deletable @deletable end |
#description ⇒ String (readonly)
The description of the benefit.
6797 6798 6799 |
# File 'lib/pago/v2026_04/models.rb', line 6797 def description @description end |
#id ⇒ String (readonly)
The ID of the benefit.
6782 6783 6784 |
# File 'lib/pago/v2026_04/models.rb', line 6782 def id @id end |
#is_deleted ⇒ Boolean (readonly)
Whether the benefit is deleted.
6809 6810 6811 |
# File 'lib/pago/v2026_04/models.rb', line 6809 def is_deleted @is_deleted end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
6816 6817 6818 |
# File 'lib/pago/v2026_04/models.rb', line 6816 def @metadata end |
#modified_at ⇒ String? (readonly)
Last modification timestamp of the object.
6790 6791 6792 |
# File 'lib/pago/v2026_04/models.rb', line 6790 def modified_at @modified_at end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the benefit.
6813 6814 6815 |
# File 'lib/pago/v2026_04/models.rb', line 6813 def organization_id @organization_id end |
#properties ⇒ Models::BenefitLicenseKeysProperties (readonly)
6822 6823 6824 |
# File 'lib/pago/v2026_04/models.rb', line 6822 def properties @properties end |
#selectable ⇒ Boolean (readonly)
Whether the benefit is selectable when creating a product.
6801 6802 6803 |
# File 'lib/pago/v2026_04/models.rb', line 6801 def selectable @selectable end |
#type ⇒ String (readonly)
6793 6794 6795 |
# File 'lib/pago/v2026_04/models.rb', line 6793 def type @type end |
#visibility ⇒ String (readonly)
6819 6820 6821 |
# File 'lib/pago/v2026_04/models.rb', line 6819 def visibility @visibility end |
#visibility_configurable ⇒ Boolean (readonly)
6825 6826 6827 |
# File 'lib/pago/v2026_04/models.rb', line 6825 def visibility_configurable @visibility_configurable end |
Class Method Details
.from_json(data) ⇒ BenefitLicenseKeys?
6860 6861 6862 6863 6864 6865 6866 6867 6868 6869 6870 6871 6872 6873 6874 6875 6876 6877 6878 6879 6880 6881 6882 6883 |
# File 'lib/pago/v2026_04/models.rb', line 6860 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), created_at: (data.key?("created_at") ? data["created_at"] : ::Pago::UNSET), modified_at: (data.key?("modified_at") ? data["modified_at"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), description: (data.key?("description") ? data["description"] : ::Pago::UNSET), selectable: (data.key?("selectable") ? data["selectable"] : ::Pago::UNSET), deletable: (data.key?("deletable") ? data["deletable"] : ::Pago::UNSET), is_deleted: (data.key?("is_deleted") ? data["is_deleted"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), visibility: (data.key?("visibility") ? data["visibility"] : ::Pago::UNSET), properties: (data.key?("properties") ? Models::BenefitLicenseKeysProperties.from_json(data["properties"]) : ::Pago::UNSET), visibility_configurable: (data.key?("visibility_configurable") ? data["visibility_configurable"] : ::Pago::UNSET) ), data ) end |