Class: Pago::V2026_04::Models::BenefitLicenseKeysCreate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ metadata: "metadata", type: "type", description: "description", organization_id: "organization_id", visibility: "visibility", properties: "properties" }.freeze
- REQUIRED_KEYS =
["type", "description", "properties"].freeze
Instance Attribute Summary collapse
-
#description ⇒ String
readonly
The description of the benefit.
-
#metadata ⇒ Hash{String => String, Integer, Float, Boolean}
readonly
Key-value object allowing you to store additional information.
-
#organization_id ⇒ String?
readonly
The ID of the organization owning the benefit.
- #properties ⇒ Models::BenefitLicenseKeysCreateProperties readonly
- #type ⇒ String readonly
-
#visibility ⇒ String?
readonly
The visibility of the benefit in the customer portal.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: ::Pago::UNSET, type:, description:, organization_id: ::Pago::UNSET, visibility: ::Pago::UNSET, properties:) ⇒ BenefitLicenseKeysCreate
constructor
A new instance of BenefitLicenseKeysCreate.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(metadata: ::Pago::UNSET, type:, description:, organization_id: ::Pago::UNSET, visibility: ::Pago::UNSET, properties:) ⇒ BenefitLicenseKeysCreate
Returns a new instance of BenefitLicenseKeysCreate.
6929 6930 6931 6932 6933 6934 6935 6936 6937 6938 6939 6940 6941 6942 6943 6944 |
# File 'lib/pago/v2026_04/models.rb', line 6929 def initialize( metadata: ::Pago::UNSET, type:, description:, organization_id: ::Pago::UNSET, visibility: ::Pago::UNSET, properties: ) super() assign(:metadata, ) assign(:type, type) assign(:description, description) assign(:organization_id, organization_id) assign(:visibility, visibility) assign(:properties, properties) end |
Instance Attribute Details
#description ⇒ String (readonly)
The description of the benefit. Will be displayed on products having this benefit.
6916 6917 6918 |
# File 'lib/pago/v2026_04/models.rb', line 6916 def description @description end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
Key-value object allowing you to store additional information.
The key must be a string with a maximum length of 40 characters. The value must be either:
- A string with a maximum length of 500 characters
- An integer
- A floating-point number
- A boolean
You can store up to 50 key-value pairs.
6909 6910 6911 |
# File 'lib/pago/v2026_04/models.rb', line 6909 def @metadata end |
#organization_id ⇒ String? (readonly)
The ID of the organization owning the benefit. Required unless you use an organization token.
6920 6921 6922 |
# File 'lib/pago/v2026_04/models.rb', line 6920 def organization_id @organization_id end |
#properties ⇒ Models::BenefitLicenseKeysCreateProperties (readonly)
6927 6928 6929 |
# File 'lib/pago/v2026_04/models.rb', line 6927 def properties @properties end |
#type ⇒ String (readonly)
6912 6913 6914 |
# File 'lib/pago/v2026_04/models.rb', line 6912 def type @type end |
#visibility ⇒ String? (readonly)
The visibility of the benefit in the customer portal.
6924 6925 6926 |
# File 'lib/pago/v2026_04/models.rb', line 6924 def visibility @visibility end |
Class Method Details
.from_json(data) ⇒ BenefitLicenseKeysCreate?
6948 6949 6950 6951 6952 6953 6954 6955 6956 6957 6958 6959 6960 6961 6962 6963 6964 |
# File 'lib/pago/v2026_04/models.rb', line 6948 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), description: (data.key?("description") ? data["description"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), visibility: (data.key?("visibility") ? data["visibility"] : ::Pago::UNSET), properties: (data.key?("properties") ? Models::BenefitLicenseKeysCreateProperties.from_json(data["properties"]) : ::Pago::UNSET) ), data ) end |