Class: Pago::V2026_04::Models::BenefitSlackSharedChannel
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ id: "id", created_at: "created_at", modified_at: "modified_at", type: "type", description: "description", selectable: "selectable", deletable: "deletable", is_deleted: "is_deleted", organization_id: "organization_id", metadata: "metadata", visibility: "visibility", properties: "properties", visibility_configurable: "visibility_configurable" }.freeze
- REQUIRED_KEYS =
["id", "created_at", "modified_at", "type", "description", "selectable", "deletable", "is_deleted", "organization_id", "metadata", "visibility", "properties", "visibility_configurable"].freeze
Instance Attribute Summary collapse
-
#created_at ⇒ String
readonly
Creation timestamp of the object.
-
#deletable ⇒ Boolean
readonly
Whether the benefit is deletable.
-
#description ⇒ String
readonly
The description of the benefit.
-
#id ⇒ String
readonly
The ID of the benefit.
-
#is_deleted ⇒ Boolean
readonly
Whether the benefit is deleted.
- #metadata ⇒ Hash{String => String, Integer, Float, Boolean} readonly
-
#modified_at ⇒ String?
readonly
Last modification timestamp of the object.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the benefit.
- #properties ⇒ Models::BenefitSlackSharedChannelProperties readonly
-
#selectable ⇒ Boolean
readonly
Whether the benefit is selectable when creating a product.
- #type ⇒ String readonly
- #visibility ⇒ String readonly
- #visibility_configurable ⇒ Boolean readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, metadata:, visibility:, properties:, visibility_configurable:) ⇒ BenefitSlackSharedChannel
constructor
A new instance of BenefitSlackSharedChannel.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, metadata:, visibility:, properties:, visibility_configurable:) ⇒ BenefitSlackSharedChannel
Returns a new instance of BenefitSlackSharedChannel.
8140 8141 8142 8143 8144 8145 8146 8147 8148 8149 8150 8151 8152 8153 8154 8155 8156 8157 8158 8159 8160 8161 8162 8163 8164 8165 8166 8167 8168 8169 |
# File 'lib/pago/v2026_04/models.rb', line 8140 def initialize( id:, created_at:, modified_at:, type:, description:, selectable:, deletable:, is_deleted:, organization_id:, metadata:, visibility:, properties:, visibility_configurable: ) super() assign(:id, id) assign(:created_at, created_at) assign(:modified_at, modified_at) assign(:type, type) assign(:description, description) assign(:selectable, selectable) assign(:deletable, deletable) assign(:is_deleted, is_deleted) assign(:organization_id, organization_id) assign(:metadata, ) assign(:visibility, visibility) assign(:properties, properties) assign(:visibility_configurable, visibility_configurable) end |
Instance Attribute Details
#created_at ⇒ String (readonly)
Creation timestamp of the object.
8099 8100 8101 |
# File 'lib/pago/v2026_04/models.rb', line 8099 def created_at @created_at end |
#deletable ⇒ Boolean (readonly)
Whether the benefit is deletable.
8118 8119 8120 |
# File 'lib/pago/v2026_04/models.rb', line 8118 def deletable @deletable end |
#description ⇒ String (readonly)
The description of the benefit.
8110 8111 8112 |
# File 'lib/pago/v2026_04/models.rb', line 8110 def description @description end |
#id ⇒ String (readonly)
The ID of the benefit.
8095 8096 8097 |
# File 'lib/pago/v2026_04/models.rb', line 8095 def id @id end |
#is_deleted ⇒ Boolean (readonly)
Whether the benefit is deleted.
8122 8123 8124 |
# File 'lib/pago/v2026_04/models.rb', line 8122 def is_deleted @is_deleted end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
8129 8130 8131 |
# File 'lib/pago/v2026_04/models.rb', line 8129 def @metadata end |
#modified_at ⇒ String? (readonly)
Last modification timestamp of the object.
8103 8104 8105 |
# File 'lib/pago/v2026_04/models.rb', line 8103 def modified_at @modified_at end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the benefit.
8126 8127 8128 |
# File 'lib/pago/v2026_04/models.rb', line 8126 def organization_id @organization_id end |
#properties ⇒ Models::BenefitSlackSharedChannelProperties (readonly)
8135 8136 8137 |
# File 'lib/pago/v2026_04/models.rb', line 8135 def properties @properties end |
#selectable ⇒ Boolean (readonly)
Whether the benefit is selectable when creating a product.
8114 8115 8116 |
# File 'lib/pago/v2026_04/models.rb', line 8114 def selectable @selectable end |
#type ⇒ String (readonly)
8106 8107 8108 |
# File 'lib/pago/v2026_04/models.rb', line 8106 def type @type end |
#visibility ⇒ String (readonly)
8132 8133 8134 |
# File 'lib/pago/v2026_04/models.rb', line 8132 def visibility @visibility end |
#visibility_configurable ⇒ Boolean (readonly)
8138 8139 8140 |
# File 'lib/pago/v2026_04/models.rb', line 8138 def visibility_configurable @visibility_configurable end |
Class Method Details
.from_json(data) ⇒ BenefitSlackSharedChannel?
8173 8174 8175 8176 8177 8178 8179 8180 8181 8182 8183 8184 8185 8186 8187 8188 8189 8190 8191 8192 8193 8194 8195 8196 |
# File 'lib/pago/v2026_04/models.rb', line 8173 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), created_at: (data.key?("created_at") ? data["created_at"] : ::Pago::UNSET), modified_at: (data.key?("modified_at") ? data["modified_at"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), description: (data.key?("description") ? data["description"] : ::Pago::UNSET), selectable: (data.key?("selectable") ? data["selectable"] : ::Pago::UNSET), deletable: (data.key?("deletable") ? data["deletable"] : ::Pago::UNSET), is_deleted: (data.key?("is_deleted") ? data["is_deleted"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), visibility: (data.key?("visibility") ? data["visibility"] : ::Pago::UNSET), properties: (data.key?("properties") ? Models::BenefitSlackSharedChannelProperties.from_json(data["properties"]) : ::Pago::UNSET), visibility_configurable: (data.key?("visibility_configurable") ? data["visibility_configurable"] : ::Pago::UNSET) ), data ) end |