Class: Pago::V2026_04::Models::BenefitSubscriberOrganization
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ created_at: "created_at", modified_at: "modified_at", id: "id", name: "name", slug: "slug", avatar_url: "avatar_url", proration_behavior: "proration_behavior", allow_customer_updates: "allow_customer_updates" }.freeze
- REQUIRED_KEYS =
["created_at", "modified_at", "id", "name", "slug", "avatar_url", "proration_behavior", "allow_customer_updates"].freeze
Instance Attribute Summary collapse
-
#allow_customer_updates ⇒ Boolean
readonly
Whether customers can update their subscriptions from the customer portal.
-
#avatar_url ⇒ String?
readonly
Avatar URL shown in checkout, customer portal, emails etc.
-
#created_at ⇒ String
readonly
Creation timestamp of the object.
-
#id ⇒ String
readonly
The ID of the object.
-
#modified_at ⇒ String?
readonly
Last modification timestamp of the object.
-
#name ⇒ String
readonly
Organization name shown in checkout, customer portal, emails etc.
- #proration_behavior ⇒ String readonly
-
#slug ⇒ String
readonly
Unique organization slug in checkout, customer portal and credit card statements.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(created_at:, modified_at:, id:, name:, slug:, avatar_url:, proration_behavior:, allow_customer_updates:) ⇒ BenefitSubscriberOrganization
constructor
A new instance of BenefitSubscriberOrganization.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(created_at:, modified_at:, id:, name:, slug:, avatar_url:, proration_behavior:, allow_customer_updates:) ⇒ BenefitSubscriberOrganization
Returns a new instance of BenefitSubscriberOrganization.
8660 8661 8662 8663 8664 8665 8666 8667 8668 8669 8670 8671 8672 8673 8674 8675 8676 8677 8678 8679 |
# File 'lib/pago/v2026_04/models.rb', line 8660 def initialize( created_at:, modified_at:, id:, name:, slug:, avatar_url:, proration_behavior:, allow_customer_updates: ) super() assign(:created_at, created_at) assign(:modified_at, modified_at) assign(:id, id) assign(:name, name) assign(:slug, slug) assign(:avatar_url, avatar_url) assign(:proration_behavior, proration_behavior) assign(:allow_customer_updates, allow_customer_updates) end |
Instance Attribute Details
#allow_customer_updates ⇒ Boolean (readonly)
Whether customers can update their subscriptions from the customer portal.
8658 8659 8660 |
# File 'lib/pago/v2026_04/models.rb', line 8658 def allow_customer_updates @allow_customer_updates end |
#avatar_url ⇒ String? (readonly)
Avatar URL shown in checkout, customer portal, emails etc.
8651 8652 8653 |
# File 'lib/pago/v2026_04/models.rb', line 8651 def avatar_url @avatar_url end |
#created_at ⇒ String (readonly)
Creation timestamp of the object.
8631 8632 8633 |
# File 'lib/pago/v2026_04/models.rb', line 8631 def created_at @created_at end |
#id ⇒ String (readonly)
The ID of the object.
8639 8640 8641 |
# File 'lib/pago/v2026_04/models.rb', line 8639 def id @id end |
#modified_at ⇒ String? (readonly)
Last modification timestamp of the object.
8635 8636 8637 |
# File 'lib/pago/v2026_04/models.rb', line 8635 def modified_at @modified_at end |
#name ⇒ String (readonly)
Organization name shown in checkout, customer portal, emails etc.
8643 8644 8645 |
# File 'lib/pago/v2026_04/models.rb', line 8643 def name @name end |
#proration_behavior ⇒ String (readonly)
8654 8655 8656 |
# File 'lib/pago/v2026_04/models.rb', line 8654 def proration_behavior @proration_behavior end |
#slug ⇒ String (readonly)
Unique organization slug in checkout, customer portal and credit card statements.
8647 8648 8649 |
# File 'lib/pago/v2026_04/models.rb', line 8647 def slug @slug end |
Class Method Details
.from_json(data) ⇒ BenefitSubscriberOrganization?
8683 8684 8685 8686 8687 8688 8689 8690 8691 8692 8693 8694 8695 8696 8697 8698 8699 8700 8701 |
# File 'lib/pago/v2026_04/models.rb', line 8683 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( created_at: (data.key?("created_at") ? data["created_at"] : ::Pago::UNSET), modified_at: (data.key?("modified_at") ? data["modified_at"] : ::Pago::UNSET), id: (data.key?("id") ? data["id"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), slug: (data.key?("slug") ? data["slug"] : ::Pago::UNSET), avatar_url: (data.key?("avatar_url") ? data["avatar_url"] : ::Pago::UNSET), proration_behavior: (data.key?("proration_behavior") ? data["proration_behavior"] : ::Pago::UNSET), allow_customer_updates: (data.key?("allow_customer_updates") ? data["allow_customer_updates"] : ::Pago::UNSET) ), data ) end |