Class: Pago::V2026_04::Models::DisputeCustomer
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ id: "id", created_at: "created_at", modified_at: "modified_at", metadata: "metadata", external_id: "external_id", email: "email", email_verified: "email_verified", type: "type", name: "name", billing_name: "billing_name", billing_address: "billing_address", tax_id: "tax_id", locale: "locale", organization_id: "organization_id", default_payment_method_id: "default_payment_method_id", deleted_at: "deleted_at", avatar_url: "avatar_url" }.freeze
- REQUIRED_KEYS =
["id", "created_at", "modified_at", "metadata", "email_verified", "type", "name", "billing_name", "billing_address", "tax_id", "organization_id", "deleted_at", "avatar_url"].freeze
Instance Attribute Summary collapse
- #avatar_url ⇒ String? readonly
- #billing_address ⇒ Models::Address? readonly
-
#billing_name ⇒ String?
readonly
The name that should appear on the customer's invoices.
-
#created_at ⇒ String
readonly
Creation timestamp of the object.
-
#default_payment_method_id ⇒ String?
readonly
The ID of the customer's default payment method, if any.
-
#deleted_at ⇒ String?
readonly
Timestamp for when the customer was soft deleted.
-
#email ⇒ String?
readonly
The email address of the customer.
-
#email_verified ⇒ Boolean
readonly
Whether the customer email address is verified.
-
#external_id ⇒ String?
readonly
The ID of the customer in your system.
-
#id ⇒ String
readonly
The ID of the customer.
- #locale ⇒ String? readonly
- #metadata ⇒ Hash{String => String, Integer, Float, Boolean} readonly
-
#modified_at ⇒ String?
readonly
Last modification timestamp of the object.
-
#name ⇒ String?
readonly
The name of the customer.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the customer.
- #tax_id ⇒ Array<Object>? readonly
- #type ⇒ String readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, modified_at:, metadata:, external_id: ::Pago::UNSET, email: ::Pago::UNSET, email_verified:, type:, name:, billing_name:, billing_address:, tax_id:, locale: ::Pago::UNSET, organization_id:, default_payment_method_id: ::Pago::UNSET, deleted_at:, avatar_url:) ⇒ DisputeCustomer
constructor
A new instance of DisputeCustomer.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, created_at:, modified_at:, metadata:, external_id: ::Pago::UNSET, email: ::Pago::UNSET, email_verified:, type:, name:, billing_name:, billing_address:, tax_id:, locale: ::Pago::UNSET, organization_id:, default_payment_method_id: ::Pago::UNSET, deleted_at:, avatar_url:) ⇒ DisputeCustomer
Returns a new instance of DisputeCustomer.
24367 24368 24369 24370 24371 24372 24373 24374 24375 24376 24377 24378 24379 24380 24381 24382 24383 24384 24385 24386 24387 24388 24389 24390 24391 24392 24393 24394 24395 24396 24397 24398 24399 24400 24401 24402 24403 24404 |
# File 'lib/pago/v2026_04/models.rb', line 24367 def initialize( id:, created_at:, modified_at:, metadata:, external_id: ::Pago::UNSET, email: ::Pago::UNSET, email_verified:, type:, name:, billing_name:, billing_address:, tax_id:, locale: ::Pago::UNSET, organization_id:, default_payment_method_id: ::Pago::UNSET, deleted_at:, avatar_url: ) super() assign(:id, id) assign(:created_at, created_at) assign(:modified_at, modified_at) assign(:metadata, ) assign(:external_id, external_id) assign(:email, email) assign(:email_verified, email_verified) assign(:type, type) assign(:name, name) assign(:billing_name, billing_name) assign(:billing_address, billing_address) assign(:tax_id, tax_id) assign(:locale, locale) assign(:organization_id, organization_id) assign(:default_payment_method_id, default_payment_method_id) assign(:deleted_at, deleted_at) assign(:avatar_url, avatar_url) end |
Instance Attribute Details
#avatar_url ⇒ String? (readonly)
24365 24366 24367 |
# File 'lib/pago/v2026_04/models.rb', line 24365 def avatar_url @avatar_url end |
#billing_address ⇒ Models::Address? (readonly)
24344 24345 24346 |
# File 'lib/pago/v2026_04/models.rb', line 24344 def billing_address @billing_address end |
#billing_name ⇒ String? (readonly)
The name that should appear on the customer's invoices. Falls back to the customer name when not explicitly set.
24341 24342 24343 |
# File 'lib/pago/v2026_04/models.rb', line 24341 def billing_name @billing_name end |
#created_at ⇒ String (readonly)
Creation timestamp of the object.
24311 24312 24313 |
# File 'lib/pago/v2026_04/models.rb', line 24311 def created_at @created_at end |
#default_payment_method_id ⇒ String? (readonly)
The ID of the customer's default payment method, if any. Use the payment methods endpoint to retrieve its details.
24358 24359 24360 |
# File 'lib/pago/v2026_04/models.rb', line 24358 def default_payment_method_id @default_payment_method_id end |
#deleted_at ⇒ String? (readonly)
Timestamp for when the customer was soft deleted.
24362 24363 24364 |
# File 'lib/pago/v2026_04/models.rb', line 24362 def deleted_at @deleted_at end |
#email ⇒ String? (readonly)
The email address of the customer. This must be unique within the organization.
24326 24327 24328 |
# File 'lib/pago/v2026_04/models.rb', line 24326 def email @email end |
#email_verified ⇒ Boolean (readonly)
Whether the customer email address is verified. The address is automatically verified when the customer accesses the customer portal using their email address.
24330 24331 24332 |
# File 'lib/pago/v2026_04/models.rb', line 24330 def email_verified @email_verified end |
#external_id ⇒ String? (readonly)
The ID of the customer in your system. This must be unique within the organization. Once set, it can't be updated.
24322 24323 24324 |
# File 'lib/pago/v2026_04/models.rb', line 24322 def external_id @external_id end |
#id ⇒ String (readonly)
The ID of the customer.
24307 24308 24309 |
# File 'lib/pago/v2026_04/models.rb', line 24307 def id @id end |
#locale ⇒ String? (readonly)
24350 24351 24352 |
# File 'lib/pago/v2026_04/models.rb', line 24350 def locale @locale end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
24318 24319 24320 |
# File 'lib/pago/v2026_04/models.rb', line 24318 def @metadata end |
#modified_at ⇒ String? (readonly)
Last modification timestamp of the object.
24315 24316 24317 |
# File 'lib/pago/v2026_04/models.rb', line 24315 def modified_at @modified_at end |
#name ⇒ String? (readonly)
The name of the customer.
24337 24338 24339 |
# File 'lib/pago/v2026_04/models.rb', line 24337 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the customer.
24354 24355 24356 |
# File 'lib/pago/v2026_04/models.rb', line 24354 def organization_id @organization_id end |
#tax_id ⇒ Array<Object>? (readonly)
24347 24348 24349 |
# File 'lib/pago/v2026_04/models.rb', line 24347 def tax_id @tax_id end |
#type ⇒ String (readonly)
24333 24334 24335 |
# File 'lib/pago/v2026_04/models.rb', line 24333 def type @type end |
Class Method Details
.from_json(data) ⇒ DisputeCustomer?
24408 24409 24410 24411 24412 24413 24414 24415 24416 24417 24418 24419 24420 24421 24422 24423 24424 24425 24426 24427 24428 24429 24430 24431 24432 24433 24434 24435 |
# File 'lib/pago/v2026_04/models.rb', line 24408 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), created_at: (data.key?("created_at") ? data["created_at"] : ::Pago::UNSET), modified_at: (data.key?("modified_at") ? data["modified_at"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), external_id: (data.key?("external_id") ? data["external_id"] : ::Pago::UNSET), email: (data.key?("email") ? data["email"] : ::Pago::UNSET), email_verified: (data.key?("email_verified") ? data["email_verified"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), billing_name: (data.key?("billing_name") ? data["billing_name"] : ::Pago::UNSET), billing_address: (data.key?("billing_address") ? Models::Address.from_json(data["billing_address"]) : ::Pago::UNSET), tax_id: (data.key?("tax_id") ? data["tax_id"] : ::Pago::UNSET), locale: (data.key?("locale") ? data["locale"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), default_payment_method_id: (data.key?("default_payment_method_id") ? data["default_payment_method_id"] : ::Pago::UNSET), deleted_at: (data.key?("deleted_at") ? data["deleted_at"] : ::Pago::UNSET), avatar_url: (data.key?("avatar_url") ? data["avatar_url"] : ::Pago::UNSET) ), data ) end |