Class: Pago::V2026_04::Models::LicenseKeyCustomer
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ id: "id", created_at: "created_at", modified_at: "modified_at", metadata: "metadata", external_id: "external_id", email: "email", email_verified: "email_verified", type: "type", name: "name", billing_name: "billing_name", billing_address: "billing_address", tax_id: "tax_id", locale: "locale", organization_id: "organization_id", default_payment_method_id: "default_payment_method_id", deleted_at: "deleted_at", avatar_url: "avatar_url" }.freeze
- REQUIRED_KEYS =
["id", "created_at", "modified_at", "metadata", "email_verified", "type", "name", "billing_name", "billing_address", "tax_id", "organization_id", "deleted_at", "avatar_url"].freeze
Instance Attribute Summary collapse
- #avatar_url ⇒ String? readonly
- #billing_address ⇒ Models::Address? readonly
-
#billing_name ⇒ String?
readonly
The name that should appear on the customer's invoices.
-
#created_at ⇒ String
readonly
Creation timestamp of the object.
-
#default_payment_method_id ⇒ String?
readonly
The ID of the customer's default payment method, if any.
-
#deleted_at ⇒ String?
readonly
Timestamp for when the customer was soft deleted.
-
#email ⇒ String?
readonly
The email address of the customer.
-
#email_verified ⇒ Boolean
readonly
Whether the customer email address is verified.
-
#external_id ⇒ String?
readonly
The ID of the customer in your system.
-
#id ⇒ String
readonly
The ID of the customer.
- #locale ⇒ String? readonly
- #metadata ⇒ Hash{String => String, Integer, Float, Boolean} readonly
-
#modified_at ⇒ String?
readonly
Last modification timestamp of the object.
-
#name ⇒ String?
readonly
The name of the customer.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the customer.
- #tax_id ⇒ Array<Object>? readonly
- #type ⇒ String readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, modified_at:, metadata:, external_id: ::Pago::UNSET, email: ::Pago::UNSET, email_verified:, type:, name:, billing_name:, billing_address:, tax_id:, locale: ::Pago::UNSET, organization_id:, default_payment_method_id: ::Pago::UNSET, deleted_at:, avatar_url:) ⇒ LicenseKeyCustomer
constructor
A new instance of LicenseKeyCustomer.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, created_at:, modified_at:, metadata:, external_id: ::Pago::UNSET, email: ::Pago::UNSET, email_verified:, type:, name:, billing_name:, billing_address:, tax_id:, locale: ::Pago::UNSET, organization_id:, default_payment_method_id: ::Pago::UNSET, deleted_at:, avatar_url:) ⇒ LicenseKeyCustomer
Returns a new instance of LicenseKeyCustomer.
26844 26845 26846 26847 26848 26849 26850 26851 26852 26853 26854 26855 26856 26857 26858 26859 26860 26861 26862 26863 26864 26865 26866 26867 26868 26869 26870 26871 26872 26873 26874 26875 26876 26877 26878 26879 26880 26881 |
# File 'lib/pago/v2026_04/models.rb', line 26844 def initialize( id:, created_at:, modified_at:, metadata:, external_id: ::Pago::UNSET, email: ::Pago::UNSET, email_verified:, type:, name:, billing_name:, billing_address:, tax_id:, locale: ::Pago::UNSET, organization_id:, default_payment_method_id: ::Pago::UNSET, deleted_at:, avatar_url: ) super() assign(:id, id) assign(:created_at, created_at) assign(:modified_at, modified_at) assign(:metadata, ) assign(:external_id, external_id) assign(:email, email) assign(:email_verified, email_verified) assign(:type, type) assign(:name, name) assign(:billing_name, billing_name) assign(:billing_address, billing_address) assign(:tax_id, tax_id) assign(:locale, locale) assign(:organization_id, organization_id) assign(:default_payment_method_id, default_payment_method_id) assign(:deleted_at, deleted_at) assign(:avatar_url, avatar_url) end |
Instance Attribute Details
#avatar_url ⇒ String? (readonly)
26842 26843 26844 |
# File 'lib/pago/v2026_04/models.rb', line 26842 def avatar_url @avatar_url end |
#billing_address ⇒ Models::Address? (readonly)
26821 26822 26823 |
# File 'lib/pago/v2026_04/models.rb', line 26821 def billing_address @billing_address end |
#billing_name ⇒ String? (readonly)
The name that should appear on the customer's invoices. Falls back to the customer name when not explicitly set.
26818 26819 26820 |
# File 'lib/pago/v2026_04/models.rb', line 26818 def billing_name @billing_name end |
#created_at ⇒ String (readonly)
Creation timestamp of the object.
26788 26789 26790 |
# File 'lib/pago/v2026_04/models.rb', line 26788 def created_at @created_at end |
#default_payment_method_id ⇒ String? (readonly)
The ID of the customer's default payment method, if any. Use the payment methods endpoint to retrieve its details.
26835 26836 26837 |
# File 'lib/pago/v2026_04/models.rb', line 26835 def default_payment_method_id @default_payment_method_id end |
#deleted_at ⇒ String? (readonly)
Timestamp for when the customer was soft deleted.
26839 26840 26841 |
# File 'lib/pago/v2026_04/models.rb', line 26839 def deleted_at @deleted_at end |
#email ⇒ String? (readonly)
The email address of the customer. This must be unique within the organization.
26803 26804 26805 |
# File 'lib/pago/v2026_04/models.rb', line 26803 def email @email end |
#email_verified ⇒ Boolean (readonly)
Whether the customer email address is verified. The address is automatically verified when the customer accesses the customer portal using their email address.
26807 26808 26809 |
# File 'lib/pago/v2026_04/models.rb', line 26807 def email_verified @email_verified end |
#external_id ⇒ String? (readonly)
The ID of the customer in your system. This must be unique within the organization. Once set, it can't be updated.
26799 26800 26801 |
# File 'lib/pago/v2026_04/models.rb', line 26799 def external_id @external_id end |
#id ⇒ String (readonly)
The ID of the customer.
26784 26785 26786 |
# File 'lib/pago/v2026_04/models.rb', line 26784 def id @id end |
#locale ⇒ String? (readonly)
26827 26828 26829 |
# File 'lib/pago/v2026_04/models.rb', line 26827 def locale @locale end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
26795 26796 26797 |
# File 'lib/pago/v2026_04/models.rb', line 26795 def @metadata end |
#modified_at ⇒ String? (readonly)
Last modification timestamp of the object.
26792 26793 26794 |
# File 'lib/pago/v2026_04/models.rb', line 26792 def modified_at @modified_at end |
#name ⇒ String? (readonly)
The name of the customer.
26814 26815 26816 |
# File 'lib/pago/v2026_04/models.rb', line 26814 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the customer.
26831 26832 26833 |
# File 'lib/pago/v2026_04/models.rb', line 26831 def organization_id @organization_id end |
#tax_id ⇒ Array<Object>? (readonly)
26824 26825 26826 |
# File 'lib/pago/v2026_04/models.rb', line 26824 def tax_id @tax_id end |
#type ⇒ String (readonly)
26810 26811 26812 |
# File 'lib/pago/v2026_04/models.rb', line 26810 def type @type end |
Class Method Details
.from_json(data) ⇒ LicenseKeyCustomer?
26885 26886 26887 26888 26889 26890 26891 26892 26893 26894 26895 26896 26897 26898 26899 26900 26901 26902 26903 26904 26905 26906 26907 26908 26909 26910 26911 26912 |
# File 'lib/pago/v2026_04/models.rb', line 26885 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), created_at: (data.key?("created_at") ? data["created_at"] : ::Pago::UNSET), modified_at: (data.key?("modified_at") ? data["modified_at"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), external_id: (data.key?("external_id") ? data["external_id"] : ::Pago::UNSET), email: (data.key?("email") ? data["email"] : ::Pago::UNSET), email_verified: (data.key?("email_verified") ? data["email_verified"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), billing_name: (data.key?("billing_name") ? data["billing_name"] : ::Pago::UNSET), billing_address: (data.key?("billing_address") ? Models::Address.from_json(data["billing_address"]) : ::Pago::UNSET), tax_id: (data.key?("tax_id") ? data["tax_id"] : ::Pago::UNSET), locale: (data.key?("locale") ? data["locale"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), default_payment_method_id: (data.key?("default_payment_method_id") ? data["default_payment_method_id"] : ::Pago::UNSET), deleted_at: (data.key?("deleted_at") ? data["deleted_at"] : ::Pago::UNSET), avatar_url: (data.key?("avatar_url") ? data["avatar_url"] : ::Pago::UNSET) ), data ) end |