Class: Pago::V2026_04::Models::OrganizationCreate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ name: "name", slug: "slug", avatar_url: "avatar_url", legal_entity: "legal_entity", email: "email", website: "website", socials: "socials", details: "details", country: "country", feature_settings: "feature_settings", subscription_settings: "subscription_settings", customer_email_settings: "customer_email_settings", customer_portal_settings: "customer_portal_settings", default_presentment_currency: "default_presentment_currency", default_tax_behavior: "default_tax_behavior" }.freeze
- REQUIRED_KEYS =
["name", "slug"].freeze
Instance Attribute Summary collapse
- #avatar_url ⇒ String? readonly
-
#country ⇒ String?
readonly
Two-letter country code (ISO 3166-1 alpha-2).
- #customer_email_settings ⇒ Models::OrganizationCustomerEmailSettings? readonly
- #customer_portal_settings ⇒ Models::OrganizationCustomerPortalSettings? readonly
- #default_presentment_currency ⇒ String readonly
- #default_tax_behavior ⇒ String readonly
-
#details ⇒ Models::OrganizationDetails?
readonly
Additional, private, business details Pago needs about active organizations for compliance (KYC).
-
#email ⇒ String?
readonly
Public support email.
- #feature_settings ⇒ Models::OrganizationFeatureSettingsUpdate? readonly
- #legal_entity ⇒ Models::OrganizationIndividualLegalEntitySchema, ... readonly
- #name ⇒ String readonly
- #slug ⇒ String readonly
-
#socials ⇒ Array<Models::OrganizationSocialLink>?
readonly
Link to social profiles.
- #subscription_settings ⇒ Models::OrganizationSubscriptionSettings? readonly
-
#website ⇒ String?
readonly
Official website of the organization.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(name:, slug:, avatar_url: ::Pago::UNSET, legal_entity: ::Pago::UNSET, email: ::Pago::UNSET, website: ::Pago::UNSET, socials: ::Pago::UNSET, details: ::Pago::UNSET, country: ::Pago::UNSET, feature_settings: ::Pago::UNSET, subscription_settings: ::Pago::UNSET, customer_email_settings: ::Pago::UNSET, customer_portal_settings: ::Pago::UNSET, default_presentment_currency: ::Pago::UNSET, default_tax_behavior: ::Pago::UNSET) ⇒ OrganizationCreate
Returns a new instance of OrganizationCreate.
34450 34451 34452 34453 34454 34455 34456 34457 34458 34459 34460 34461 34462 34463 34464 34465 34466 34467 34468 34469 34470 34471 34472 34473 34474 34475 34476 34477 34478 34479 34480 34481 34482 34483 |
# File 'lib/pago/v2026_04/models.rb', line 34450 def initialize( name:, slug:, avatar_url: ::Pago::UNSET, legal_entity: ::Pago::UNSET, email: ::Pago::UNSET, website: ::Pago::UNSET, socials: ::Pago::UNSET, details: ::Pago::UNSET, country: ::Pago::UNSET, feature_settings: ::Pago::UNSET, subscription_settings: ::Pago::UNSET, customer_email_settings: ::Pago::UNSET, customer_portal_settings: ::Pago::UNSET, default_presentment_currency: ::Pago::UNSET, default_tax_behavior: ::Pago::UNSET ) super() assign(:name, name) assign(:slug, slug) assign(:avatar_url, avatar_url) assign(:legal_entity, legal_entity) assign(:email, email) assign(:website, website) assign(:socials, ) assign(:details, details) assign(:country, country) assign(:feature_settings, feature_settings) assign(:subscription_settings, subscription_settings) assign(:customer_email_settings, customer_email_settings) assign(:customer_portal_settings, customer_portal_settings) assign(:default_presentment_currency, default_presentment_currency) assign(:default_tax_behavior, default_tax_behavior) end |
Instance Attribute Details
#avatar_url ⇒ String? (readonly)
34407 34408 34409 |
# File 'lib/pago/v2026_04/models.rb', line 34407 def avatar_url @avatar_url end |
#country ⇒ String? (readonly)
Two-letter country code (ISO 3166-1 alpha-2).
34430 34431 34432 |
# File 'lib/pago/v2026_04/models.rb', line 34430 def country @country end |
#customer_email_settings ⇒ Models::OrganizationCustomerEmailSettings? (readonly)
34439 34440 34441 |
# File 'lib/pago/v2026_04/models.rb', line 34439 def customer_email_settings @customer_email_settings end |
#customer_portal_settings ⇒ Models::OrganizationCustomerPortalSettings? (readonly)
34442 34443 34444 |
# File 'lib/pago/v2026_04/models.rb', line 34442 def customer_portal_settings @customer_portal_settings end |
#default_presentment_currency ⇒ String (readonly)
34445 34446 34447 |
# File 'lib/pago/v2026_04/models.rb', line 34445 def default_presentment_currency @default_presentment_currency end |
#default_tax_behavior ⇒ String (readonly)
34448 34449 34450 |
# File 'lib/pago/v2026_04/models.rb', line 34448 def default_tax_behavior @default_tax_behavior end |
#details ⇒ Models::OrganizationDetails? (readonly)
Additional, private, business details Pago needs about active organizations for compliance (KYC).
34426 34427 34428 |
# File 'lib/pago/v2026_04/models.rb', line 34426 def details @details end |
#email ⇒ String? (readonly)
Public support email.
34414 34415 34416 |
# File 'lib/pago/v2026_04/models.rb', line 34414 def email @email end |
#feature_settings ⇒ Models::OrganizationFeatureSettingsUpdate? (readonly)
34433 34434 34435 |
# File 'lib/pago/v2026_04/models.rb', line 34433 def feature_settings @feature_settings end |
#legal_entity ⇒ Models::OrganizationIndividualLegalEntitySchema, ... (readonly)
34410 34411 34412 |
# File 'lib/pago/v2026_04/models.rb', line 34410 def legal_entity @legal_entity end |
#name ⇒ String (readonly)
34401 34402 34403 |
# File 'lib/pago/v2026_04/models.rb', line 34401 def name @name end |
#slug ⇒ String (readonly)
34404 34405 34406 |
# File 'lib/pago/v2026_04/models.rb', line 34404 def slug @slug end |
#socials ⇒ Array<Models::OrganizationSocialLink>? (readonly)
Link to social profiles.
34422 34423 34424 |
# File 'lib/pago/v2026_04/models.rb', line 34422 def @socials end |
#subscription_settings ⇒ Models::OrganizationSubscriptionSettings? (readonly)
34436 34437 34438 |
# File 'lib/pago/v2026_04/models.rb', line 34436 def subscription_settings @subscription_settings end |
#website ⇒ String? (readonly)
Official website of the organization.
34418 34419 34420 |
# File 'lib/pago/v2026_04/models.rb', line 34418 def website @website end |
Class Method Details
.from_json(data) ⇒ OrganizationCreate?
34487 34488 34489 34490 34491 34492 34493 34494 34495 34496 34497 34498 34499 34500 34501 34502 34503 34504 34505 34506 34507 34508 34509 34510 34511 34512 |
# File 'lib/pago/v2026_04/models.rb', line 34487 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( name: (data.key?("name") ? data["name"] : ::Pago::UNSET), slug: (data.key?("slug") ? data["slug"] : ::Pago::UNSET), avatar_url: (data.key?("avatar_url") ? data["avatar_url"] : ::Pago::UNSET), legal_entity: (data.key?("legal_entity") ? ::Pago::Serde.union(data["legal_entity"], discriminator: "type", mapping: { "company" => Models::OrganizationCompanyLegalEntitySchema, "individual" => Models::OrganizationIndividualLegalEntitySchema }, variants: [Models::OrganizationIndividualLegalEntitySchema, Models::OrganizationCompanyLegalEntitySchema]) : ::Pago::UNSET), email: (data.key?("email") ? data["email"] : ::Pago::UNSET), website: (data.key?("website") ? data["website"] : ::Pago::UNSET), socials: (data.key?("socials") ? ::Pago::Serde.array(data["socials"]) { |item0| Models::OrganizationSocialLink.from_json(item0) } : ::Pago::UNSET), details: (data.key?("details") ? Models::OrganizationDetails.from_json(data["details"]) : ::Pago::UNSET), country: (data.key?("country") ? data["country"] : ::Pago::UNSET), feature_settings: (data.key?("feature_settings") ? Models::OrganizationFeatureSettingsUpdate.from_json(data["feature_settings"]) : ::Pago::UNSET), subscription_settings: (data.key?("subscription_settings") ? Models::OrganizationSubscriptionSettings.from_json(data["subscription_settings"]) : ::Pago::UNSET), customer_email_settings: (data.key?("customer_email_settings") ? Models::OrganizationCustomerEmailSettings.from_json(data["customer_email_settings"]) : ::Pago::UNSET), customer_portal_settings: (data.key?("customer_portal_settings") ? Models::OrganizationCustomerPortalSettings.from_json(data["customer_portal_settings"]) : ::Pago::UNSET), default_presentment_currency: (data.key?("default_presentment_currency") ? data["default_presentment_currency"] : ::Pago::UNSET), default_tax_behavior: (data.key?("default_tax_behavior") ? data["default_tax_behavior"] : ::Pago::UNSET) ), data ) end |