Class: Pago::V2026_04::Models::OrganizationFeatureSettings
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ issue_funding_enabled: "issue_funding_enabled", seat_based_pricing_enabled: "seat_based_pricing_enabled", wallets_enabled: "wallets_enabled", member_model_enabled: "member_model_enabled", checkout_localization_enabled: "checkout_localization_enabled", overview_metrics: "overview_metrics", reset_proration_behavior_enabled: "reset_proration_behavior_enabled", off_session_charges_enabled: "off_session_charges_enabled", slack_benefit_enabled: "slack_benefit_enabled", preview_access_enabled: "preview_access_enabled", disputes_enabled: "disputes_enabled", sso_enabled: "sso_enabled", compass_enabled: "compass_enabled", merchant_migration_enabled: "merchant_migration_enabled" }.freeze
- REQUIRED_KEYS =
[].freeze
Instance Attribute Summary collapse
-
#checkout_localization_enabled ⇒ Boolean
readonly
If this organization has checkout localization enabled.
-
#compass_enabled ⇒ Boolean
readonly
If this organization has the split product navigation (Billing / Compass / Customers) enabled in the dashboard.
-
#disputes_enabled ⇒ Boolean
readonly
If this organization has the disputes dashboard enabled.
-
#issue_funding_enabled ⇒ Boolean
readonly
If this organization has issue funding enabled.
-
#member_model_enabled ⇒ Boolean
readonly
If this organization has the Member model enabled.
-
#merchant_migration_enabled ⇒ Boolean
readonly
If this organization can migrate its billing from another provider (e.g. Stripe) to Pago.
-
#off_session_charges_enabled ⇒ Boolean
readonly
If this organization can create and finalize draft orders via the API (off-session charges against a saved payment method).
-
#overview_metrics ⇒ Array<String>?
readonly
Ordered list of metric slugs shown on the dashboard overview.
-
#preview_access_enabled ⇒ Boolean
readonly
If this organization has preview access to new features enabled.
-
#reset_proration_behavior_enabled ⇒ Boolean
readonly
If this organization has access to reset proration behavior.
-
#seat_based_pricing_enabled ⇒ Boolean
readonly
If this organization has seat-based pricing enabled.
-
#slack_benefit_enabled ⇒ Boolean
readonly
Enables the slack shared channel benefit.
-
#sso_enabled ⇒ Boolean
readonly
If this organization has single sign-on configuration enabled.
-
#wallets_enabled ⇒ Boolean
readonly
If this organization has Wallets enabled.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(issue_funding_enabled: ::Pago::UNSET, seat_based_pricing_enabled: ::Pago::UNSET, wallets_enabled: ::Pago::UNSET, member_model_enabled: ::Pago::UNSET, checkout_localization_enabled: ::Pago::UNSET, overview_metrics: ::Pago::UNSET, reset_proration_behavior_enabled: ::Pago::UNSET, off_session_charges_enabled: ::Pago::UNSET, slack_benefit_enabled: ::Pago::UNSET, preview_access_enabled: ::Pago::UNSET, disputes_enabled: ::Pago::UNSET, sso_enabled: ::Pago::UNSET, compass_enabled: ::Pago::UNSET, merchant_migration_enabled: ::Pago::UNSET) ⇒ OrganizationFeatureSettings
Returns a new instance of OrganizationFeatureSettings.
34862 34863 34864 34865 34866 34867 34868 34869 34870 34871 34872 34873 34874 34875 34876 34877 34878 34879 34880 34881 34882 34883 34884 34885 34886 34887 34888 34889 34890 34891 34892 34893 |
# File 'lib/pago/v2026_04/models.rb', line 34862 def initialize( issue_funding_enabled: ::Pago::UNSET, seat_based_pricing_enabled: ::Pago::UNSET, wallets_enabled: ::Pago::UNSET, member_model_enabled: ::Pago::UNSET, checkout_localization_enabled: ::Pago::UNSET, overview_metrics: ::Pago::UNSET, reset_proration_behavior_enabled: ::Pago::UNSET, off_session_charges_enabled: ::Pago::UNSET, slack_benefit_enabled: ::Pago::UNSET, preview_access_enabled: ::Pago::UNSET, disputes_enabled: ::Pago::UNSET, sso_enabled: ::Pago::UNSET, compass_enabled: ::Pago::UNSET, merchant_migration_enabled: ::Pago::UNSET ) super() assign(:issue_funding_enabled, issue_funding_enabled) assign(:seat_based_pricing_enabled, seat_based_pricing_enabled) assign(:wallets_enabled, wallets_enabled) assign(:member_model_enabled, member_model_enabled) assign(:checkout_localization_enabled, checkout_localization_enabled) assign(:overview_metrics, overview_metrics) assign(:reset_proration_behavior_enabled, reset_proration_behavior_enabled) assign(:off_session_charges_enabled, off_session_charges_enabled) assign(:slack_benefit_enabled, slack_benefit_enabled) assign(:preview_access_enabled, preview_access_enabled) assign(:disputes_enabled, disputes_enabled) assign(:sso_enabled, sso_enabled) assign(:compass_enabled, compass_enabled) assign(:merchant_migration_enabled, merchant_migration_enabled) end |
Instance Attribute Details
#checkout_localization_enabled ⇒ Boolean (readonly)
If this organization has checkout localization enabled
34824 34825 34826 |
# File 'lib/pago/v2026_04/models.rb', line 34824 def checkout_localization_enabled @checkout_localization_enabled end |
#compass_enabled ⇒ Boolean (readonly)
If this organization has the split product navigation (Billing / Compass / Customers) enabled in the dashboard
34856 34857 34858 |
# File 'lib/pago/v2026_04/models.rb', line 34856 def compass_enabled @compass_enabled end |
#disputes_enabled ⇒ Boolean (readonly)
If this organization has the disputes dashboard enabled
34848 34849 34850 |
# File 'lib/pago/v2026_04/models.rb', line 34848 def disputes_enabled @disputes_enabled end |
#issue_funding_enabled ⇒ Boolean (readonly)
If this organization has issue funding enabled
34808 34809 34810 |
# File 'lib/pago/v2026_04/models.rb', line 34808 def issue_funding_enabled @issue_funding_enabled end |
#member_model_enabled ⇒ Boolean (readonly)
If this organization has the Member model enabled
34820 34821 34822 |
# File 'lib/pago/v2026_04/models.rb', line 34820 def member_model_enabled @member_model_enabled end |
#merchant_migration_enabled ⇒ Boolean (readonly)
If this organization can migrate its billing from another provider (e.g. Stripe) to Pago.
34860 34861 34862 |
# File 'lib/pago/v2026_04/models.rb', line 34860 def merchant_migration_enabled @merchant_migration_enabled end |
#off_session_charges_enabled ⇒ Boolean (readonly)
If this organization can create and finalize draft orders via the API (off-session charges against a saved payment method).
34836 34837 34838 |
# File 'lib/pago/v2026_04/models.rb', line 34836 def off_session_charges_enabled @off_session_charges_enabled end |
#overview_metrics ⇒ Array<String>? (readonly)
Ordered list of metric slugs shown on the dashboard overview.
34828 34829 34830 |
# File 'lib/pago/v2026_04/models.rb', line 34828 def overview_metrics @overview_metrics end |
#preview_access_enabled ⇒ Boolean (readonly)
If this organization has preview access to new features enabled
34844 34845 34846 |
# File 'lib/pago/v2026_04/models.rb', line 34844 def preview_access_enabled @preview_access_enabled end |
#reset_proration_behavior_enabled ⇒ Boolean (readonly)
If this organization has access to reset proration behavior.
34832 34833 34834 |
# File 'lib/pago/v2026_04/models.rb', line 34832 def reset_proration_behavior_enabled @reset_proration_behavior_enabled end |
#seat_based_pricing_enabled ⇒ Boolean (readonly)
If this organization has seat-based pricing enabled
34812 34813 34814 |
# File 'lib/pago/v2026_04/models.rb', line 34812 def seat_based_pricing_enabled @seat_based_pricing_enabled end |
#slack_benefit_enabled ⇒ Boolean (readonly)
Enables the slack shared channel benefit
34840 34841 34842 |
# File 'lib/pago/v2026_04/models.rb', line 34840 def slack_benefit_enabled @slack_benefit_enabled end |
#sso_enabled ⇒ Boolean (readonly)
If this organization has single sign-on configuration enabled
34852 34853 34854 |
# File 'lib/pago/v2026_04/models.rb', line 34852 def sso_enabled @sso_enabled end |
#wallets_enabled ⇒ Boolean (readonly)
If this organization has Wallets enabled
34816 34817 34818 |
# File 'lib/pago/v2026_04/models.rb', line 34816 def wallets_enabled @wallets_enabled end |
Class Method Details
.from_json(data) ⇒ OrganizationFeatureSettings?
34897 34898 34899 34900 34901 34902 34903 34904 34905 34906 34907 34908 34909 34910 34911 34912 34913 34914 34915 34916 34917 34918 34919 34920 34921 |
# File 'lib/pago/v2026_04/models.rb', line 34897 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( issue_funding_enabled: (data.key?("issue_funding_enabled") ? data["issue_funding_enabled"] : ::Pago::UNSET), seat_based_pricing_enabled: (data.key?("seat_based_pricing_enabled") ? data["seat_based_pricing_enabled"] : ::Pago::UNSET), wallets_enabled: (data.key?("wallets_enabled") ? data["wallets_enabled"] : ::Pago::UNSET), member_model_enabled: (data.key?("member_model_enabled") ? data["member_model_enabled"] : ::Pago::UNSET), checkout_localization_enabled: (data.key?("checkout_localization_enabled") ? data["checkout_localization_enabled"] : ::Pago::UNSET), overview_metrics: (data.key?("overview_metrics") ? data["overview_metrics"] : ::Pago::UNSET), reset_proration_behavior_enabled: (data.key?("reset_proration_behavior_enabled") ? data["reset_proration_behavior_enabled"] : ::Pago::UNSET), off_session_charges_enabled: (data.key?("off_session_charges_enabled") ? data["off_session_charges_enabled"] : ::Pago::UNSET), slack_benefit_enabled: (data.key?("slack_benefit_enabled") ? data["slack_benefit_enabled"] : ::Pago::UNSET), preview_access_enabled: (data.key?("preview_access_enabled") ? data["preview_access_enabled"] : ::Pago::UNSET), disputes_enabled: (data.key?("disputes_enabled") ? data["disputes_enabled"] : ::Pago::UNSET), sso_enabled: (data.key?("sso_enabled") ? data["sso_enabled"] : ::Pago::UNSET), compass_enabled: (data.key?("compass_enabled") ? data["compass_enabled"] : ::Pago::UNSET), merchant_migration_enabled: (data.key?("merchant_migration_enabled") ? data["merchant_migration_enabled"] : ::Pago::UNSET) ), data ) end |