Class: Pago::V2026_04::Models::OrganizationUpdate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ name: "name", avatar_url: "avatar_url", email: "email", website: "website", socials: "socials", details: "details", country: "country", feature_settings: "feature_settings", subscription_settings: "subscription_settings", customer_email_settings: "customer_email_settings", customer_portal_settings: "customer_portal_settings", default_presentment_currency: "default_presentment_currency", default_tax_behavior: "default_tax_behavior", sso_enforced: "sso_enforced" }.freeze
- REQUIRED_KEYS =
[].freeze
Instance Attribute Summary collapse
- #avatar_url ⇒ String? readonly
-
#country ⇒ String?
readonly
Two-letter country code (ISO 3166-1 alpha-2).
- #customer_email_settings ⇒ Models::OrganizationCustomerEmailSettings? readonly
- #customer_portal_settings ⇒ Models::OrganizationCustomerPortalSettings? readonly
-
#default_presentment_currency ⇒ String?
readonly
Default presentment currency for the organization.
-
#default_tax_behavior ⇒ String?
readonly
Default tax behavior applied on products.
-
#details ⇒ Models::OrganizationDetails?
readonly
Additional, private, business details Pago needs about active organizations for compliance (KYC).
-
#email ⇒ String?
readonly
Public support email.
- #feature_settings ⇒ Models::OrganizationFeatureSettingsUpdate? readonly
- #name ⇒ String? readonly
-
#socials ⇒ Array<Models::OrganizationSocialLink>?
readonly
Links to social profiles.
-
#sso_enforced ⇒ Boolean?
readonly
Whether members must access this organization through its SSO connection.
- #subscription_settings ⇒ Models::OrganizationSubscriptionSettings? readonly
-
#website ⇒ String?
readonly
Official website of the organization.
Class Method Summary collapse
Instance Method Summary collapse
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(name: ::Pago::UNSET, avatar_url: ::Pago::UNSET, email: ::Pago::UNSET, website: ::Pago::UNSET, socials: ::Pago::UNSET, details: ::Pago::UNSET, country: ::Pago::UNSET, feature_settings: ::Pago::UNSET, subscription_settings: ::Pago::UNSET, customer_email_settings: ::Pago::UNSET, customer_portal_settings: ::Pago::UNSET, default_presentment_currency: ::Pago::UNSET, default_tax_behavior: ::Pago::UNSET, sso_enforced: ::Pago::UNSET) ⇒ OrganizationUpdate
Returns a new instance of OrganizationUpdate.
35225 35226 35227 35228 35229 35230 35231 35232 35233 35234 35235 35236 35237 35238 35239 35240 35241 35242 35243 35244 35245 35246 35247 35248 35249 35250 35251 35252 35253 35254 35255 35256 |
# File 'lib/pago/v2026_04/models.rb', line 35225 def initialize( name: ::Pago::UNSET, avatar_url: ::Pago::UNSET, email: ::Pago::UNSET, website: ::Pago::UNSET, socials: ::Pago::UNSET, details: ::Pago::UNSET, country: ::Pago::UNSET, feature_settings: ::Pago::UNSET, subscription_settings: ::Pago::UNSET, customer_email_settings: ::Pago::UNSET, customer_portal_settings: ::Pago::UNSET, default_presentment_currency: ::Pago::UNSET, default_tax_behavior: ::Pago::UNSET, sso_enforced: ::Pago::UNSET ) super() assign(:name, name) assign(:avatar_url, avatar_url) assign(:email, email) assign(:website, website) assign(:socials, ) assign(:details, details) assign(:country, country) assign(:feature_settings, feature_settings) assign(:subscription_settings, subscription_settings) assign(:customer_email_settings, customer_email_settings) assign(:customer_portal_settings, customer_portal_settings) assign(:default_presentment_currency, default_presentment_currency) assign(:default_tax_behavior, default_tax_behavior) assign(:sso_enforced, sso_enforced) end |
Instance Attribute Details
#avatar_url ⇒ String? (readonly)
35179 35180 35181 |
# File 'lib/pago/v2026_04/models.rb', line 35179 def avatar_url @avatar_url end |
#country ⇒ String? (readonly)
Two-letter country code (ISO 3166-1 alpha-2).
35199 35200 35201 |
# File 'lib/pago/v2026_04/models.rb', line 35199 def country @country end |
#customer_email_settings ⇒ Models::OrganizationCustomerEmailSettings? (readonly)
35208 35209 35210 |
# File 'lib/pago/v2026_04/models.rb', line 35208 def customer_email_settings @customer_email_settings end |
#customer_portal_settings ⇒ Models::OrganizationCustomerPortalSettings? (readonly)
35211 35212 35213 |
# File 'lib/pago/v2026_04/models.rb', line 35211 def customer_portal_settings @customer_portal_settings end |
#default_presentment_currency ⇒ String? (readonly)
Default presentment currency for the organization
35215 35216 35217 |
# File 'lib/pago/v2026_04/models.rb', line 35215 def default_presentment_currency @default_presentment_currency end |
#default_tax_behavior ⇒ String? (readonly)
Default tax behavior applied on products.
35219 35220 35221 |
# File 'lib/pago/v2026_04/models.rb', line 35219 def default_tax_behavior @default_tax_behavior end |
#details ⇒ Models::OrganizationDetails? (readonly)
Additional, private, business details Pago needs about active organizations for compliance (KYC).
35195 35196 35197 |
# File 'lib/pago/v2026_04/models.rb', line 35195 def details @details end |
#email ⇒ String? (readonly)
Public support email.
35183 35184 35185 |
# File 'lib/pago/v2026_04/models.rb', line 35183 def email @email end |
#feature_settings ⇒ Models::OrganizationFeatureSettingsUpdate? (readonly)
35202 35203 35204 |
# File 'lib/pago/v2026_04/models.rb', line 35202 def feature_settings @feature_settings end |
#name ⇒ String? (readonly)
35176 35177 35178 |
# File 'lib/pago/v2026_04/models.rb', line 35176 def name @name end |
#socials ⇒ Array<Models::OrganizationSocialLink>? (readonly)
Links to social profiles.
35191 35192 35193 |
# File 'lib/pago/v2026_04/models.rb', line 35191 def @socials end |
#sso_enforced ⇒ Boolean? (readonly)
Whether members must access this organization through its SSO connection. Turning this on requires an active SSO session for this organization and at least one enabled SSO connection.
35223 35224 35225 |
# File 'lib/pago/v2026_04/models.rb', line 35223 def sso_enforced @sso_enforced end |
#subscription_settings ⇒ Models::OrganizationSubscriptionSettings? (readonly)
35205 35206 35207 |
# File 'lib/pago/v2026_04/models.rb', line 35205 def subscription_settings @subscription_settings end |
#website ⇒ String? (readonly)
Official website of the organization.
35187 35188 35189 |
# File 'lib/pago/v2026_04/models.rb', line 35187 def website @website end |
Class Method Details
.from_json(data) ⇒ OrganizationUpdate?
35260 35261 35262 35263 35264 35265 35266 35267 35268 35269 35270 35271 35272 35273 35274 35275 35276 35277 35278 35279 35280 35281 35282 35283 35284 |
# File 'lib/pago/v2026_04/models.rb', line 35260 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( name: (data.key?("name") ? data["name"] : ::Pago::UNSET), avatar_url: (data.key?("avatar_url") ? data["avatar_url"] : ::Pago::UNSET), email: (data.key?("email") ? data["email"] : ::Pago::UNSET), website: (data.key?("website") ? data["website"] : ::Pago::UNSET), socials: (data.key?("socials") ? ::Pago::Serde.array(data["socials"]) { |item0| Models::OrganizationSocialLink.from_json(item0) } : ::Pago::UNSET), details: (data.key?("details") ? Models::OrganizationDetails.from_json(data["details"]) : ::Pago::UNSET), country: (data.key?("country") ? data["country"] : ::Pago::UNSET), feature_settings: (data.key?("feature_settings") ? Models::OrganizationFeatureSettingsUpdate.from_json(data["feature_settings"]) : ::Pago::UNSET), subscription_settings: (data.key?("subscription_settings") ? Models::OrganizationSubscriptionSettings.from_json(data["subscription_settings"]) : ::Pago::UNSET), customer_email_settings: (data.key?("customer_email_settings") ? Models::OrganizationCustomerEmailSettings.from_json(data["customer_email_settings"]) : ::Pago::UNSET), customer_portal_settings: (data.key?("customer_portal_settings") ? Models::OrganizationCustomerPortalSettings.from_json(data["customer_portal_settings"]) : ::Pago::UNSET), default_presentment_currency: (data.key?("default_presentment_currency") ? data["default_presentment_currency"] : ::Pago::UNSET), default_tax_behavior: (data.key?("default_tax_behavior") ? data["default_tax_behavior"] : ::Pago::UNSET), sso_enforced: (data.key?("sso_enforced") ? data["sso_enforced"] : ::Pago::UNSET) ), data ) end |