Class: Pago::V2026_04::Models::WebhookEndpointUpdate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
Schema to update a webhook endpoint.
Constant Summary collapse
- JSON_KEYS =
{ url: "url", name: "name", format: "format", events: "events", enabled: "enabled" }.freeze
- REQUIRED_KEYS =
[].freeze
Instance Attribute Summary collapse
-
#enabled ⇒ Boolean?
readonly
Whether the webhook endpoint is enabled.
- #events ⇒ Array<String>? readonly
- #format ⇒ String? readonly
-
#name ⇒ String?
readonly
An optional name for the webhook endpoint to help organize and identify it.
- #url ⇒ String? readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(url: ::Pago::UNSET, name: ::Pago::UNSET, format: ::Pago::UNSET, events: ::Pago::UNSET, enabled: ::Pago::UNSET) ⇒ WebhookEndpointUpdate
constructor
A new instance of WebhookEndpointUpdate.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(url: ::Pago::UNSET, name: ::Pago::UNSET, format: ::Pago::UNSET, events: ::Pago::UNSET, enabled: ::Pago::UNSET) ⇒ WebhookEndpointUpdate
Returns a new instance of WebhookEndpointUpdate.
44318 44319 44320 44321 44322 44323 44324 44325 44326 44327 44328 44329 44330 44331 |
# File 'lib/pago/v2026_04/models.rb', line 44318 def initialize( url: ::Pago::UNSET, name: ::Pago::UNSET, format: ::Pago::UNSET, events: ::Pago::UNSET, enabled: ::Pago::UNSET ) super() assign(:url, url) assign(:name, name) assign(:format, format) assign(:events, events) assign(:enabled, enabled) end |
Instance Attribute Details
#enabled ⇒ Boolean? (readonly)
Whether the webhook endpoint is enabled.
44316 44317 44318 |
# File 'lib/pago/v2026_04/models.rb', line 44316 def enabled @enabled end |
#events ⇒ Array<String>? (readonly)
44312 44313 44314 |
# File 'lib/pago/v2026_04/models.rb', line 44312 def events @events end |
#format ⇒ String? (readonly)
44309 44310 44311 |
# File 'lib/pago/v2026_04/models.rb', line 44309 def format @format end |
#name ⇒ String? (readonly)
An optional name for the webhook endpoint to help organize and identify it.
44306 44307 44308 |
# File 'lib/pago/v2026_04/models.rb', line 44306 def name @name end |
#url ⇒ String? (readonly)
44302 44303 44304 |
# File 'lib/pago/v2026_04/models.rb', line 44302 def url @url end |
Class Method Details
.from_json(data) ⇒ WebhookEndpointUpdate?
44335 44336 44337 44338 44339 44340 44341 44342 44343 44344 44345 44346 44347 44348 44349 44350 |
# File 'lib/pago/v2026_04/models.rb', line 44335 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( url: (data.key?("url") ? data["url"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), format: (data.key?("format") ? data["format"] : ::Pago::UNSET), events: (data.key?("events") ? data["events"] : ::Pago::UNSET), enabled: (data.key?("enabled") ? data["enabled"] : ::Pago::UNSET) ), data ) end |