Class: Pago::V2026_04::Models::WebhookMemberUpdatedPayload
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
Sent when a member is updated.
This event is triggered when member details are updated, such as their name or role within the customer.
Discord & Slack support: Basic
Constant Summary collapse
- JSON_KEYS =
{ type: "type", timestamp: "timestamp", data: "data" }.freeze
- REQUIRED_KEYS =
["type", "timestamp", "data"].freeze
Instance Attribute Summary collapse
- #data ⇒ Models::Member readonly
- #timestamp ⇒ String readonly
- #type ⇒ String readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(type:, timestamp:, data:) ⇒ WebhookMemberUpdatedPayload
constructor
A new instance of WebhookMemberUpdatedPayload.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(type:, timestamp:, data:) ⇒ WebhookMemberUpdatedPayload
Returns a new instance of WebhookMemberUpdatedPayload.
45389 45390 45391 45392 45393 45394 45395 45396 45397 45398 |
# File 'lib/pago/v2026_04/models.rb', line 45389 def initialize( type:, timestamp:, data: ) super() assign(:type, type) assign(:timestamp, ) assign(:data, data) end |
Instance Attribute Details
#data ⇒ Models::Member (readonly)
45387 45388 45389 |
# File 'lib/pago/v2026_04/models.rb', line 45387 def data @data end |
#timestamp ⇒ String (readonly)
45384 45385 45386 |
# File 'lib/pago/v2026_04/models.rb', line 45384 def @timestamp end |
#type ⇒ String (readonly)
45381 45382 45383 |
# File 'lib/pago/v2026_04/models.rb', line 45381 def type @type end |
Class Method Details
.from_json(data) ⇒ WebhookMemberUpdatedPayload?
45402 45403 45404 45405 45406 45407 45408 45409 45410 45411 45412 45413 45414 45415 |
# File 'lib/pago/v2026_04/models.rb', line 45402 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( type: (data.key?("type") ? data["type"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), data: (data.key?("data") ? Models::Member.from_json(data["data"]) : ::Pago::UNSET) ), data ) end |