Class: Pago::V2026_04::Models::BalanceDisputeEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when an order is disputed.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::BalanceDisputeMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ BalanceDisputeEvent
constructor
A new instance of BalanceDisputeEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ BalanceDisputeEvent
Returns a new instance of BalanceDisputeEvent.
974 975 976 977 978 979 980 981 982 983 984 985 986 987 988 989 990 991 992 993 994 995 996 997 998 999 1000 1001 1002 1003 1004 1005 |
# File 'lib/pago/v2026_04/models.rb', line 974 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
953 954 955 |
# File 'lib/pago/v2026_04/models.rb', line 953 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
937 938 939 |
# File 'lib/pago/v2026_04/models.rb', line 937 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
933 934 935 |
# File 'lib/pago/v2026_04/models.rb', line 933 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
941 942 943 |
# File 'lib/pago/v2026_04/models.rb', line 941 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
949 950 951 |
# File 'lib/pago/v2026_04/models.rb', line 949 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
921 922 923 |
# File 'lib/pago/v2026_04/models.rb', line 921 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
961 962 963 |
# File 'lib/pago/v2026_04/models.rb', line 961 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
945 946 947 |
# File 'lib/pago/v2026_04/models.rb', line 945 def member_id @member_id end |
#metadata ⇒ Models::BalanceDisputeMetadata (readonly)
972 973 974 |
# File 'lib/pago/v2026_04/models.rb', line 972 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
969 970 971 |
# File 'lib/pago/v2026_04/models.rb', line 969 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
929 930 931 |
# File 'lib/pago/v2026_04/models.rb', line 929 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
957 958 959 |
# File 'lib/pago/v2026_04/models.rb', line 957 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
965 966 967 |
# File 'lib/pago/v2026_04/models.rb', line 965 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
925 926 927 |
# File 'lib/pago/v2026_04/models.rb', line 925 def @timestamp end |
Class Method Details
.from_json(data) ⇒ BalanceDisputeEvent?
1009 1010 1011 1012 1013 1014 1015 1016 1017 1018 1019 1020 1021 1022 1023 1024 1025 1026 1027 1028 1029 1030 1031 1032 1033 |
# File 'lib/pago/v2026_04/models.rb', line 1009 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::BalanceDisputeMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |