Class: Pago::V2026_04::Models::BalanceOrderEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when an order is paid.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::BalanceOrderMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ BalanceOrderEvent
constructor
A new instance of BalanceOrderEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ BalanceOrderEvent
Returns a new instance of BalanceOrderEvent.
1378 1379 1380 1381 1382 1383 1384 1385 1386 1387 1388 1389 1390 1391 1392 1393 1394 1395 1396 1397 1398 1399 1400 1401 1402 1403 1404 1405 1406 1407 1408 1409 |
# File 'lib/pago/v2026_04/models.rb', line 1378 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
1357 1358 1359 |
# File 'lib/pago/v2026_04/models.rb', line 1357 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
1341 1342 1343 |
# File 'lib/pago/v2026_04/models.rb', line 1341 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
1337 1338 1339 |
# File 'lib/pago/v2026_04/models.rb', line 1337 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
1345 1346 1347 |
# File 'lib/pago/v2026_04/models.rb', line 1345 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
1353 1354 1355 |
# File 'lib/pago/v2026_04/models.rb', line 1353 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
1325 1326 1327 |
# File 'lib/pago/v2026_04/models.rb', line 1325 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
1365 1366 1367 |
# File 'lib/pago/v2026_04/models.rb', line 1365 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
1349 1350 1351 |
# File 'lib/pago/v2026_04/models.rb', line 1349 def member_id @member_id end |
#metadata ⇒ Models::BalanceOrderMetadata (readonly)
1376 1377 1378 |
# File 'lib/pago/v2026_04/models.rb', line 1376 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
1373 1374 1375 |
# File 'lib/pago/v2026_04/models.rb', line 1373 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
1333 1334 1335 |
# File 'lib/pago/v2026_04/models.rb', line 1333 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
1361 1362 1363 |
# File 'lib/pago/v2026_04/models.rb', line 1361 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
1369 1370 1371 |
# File 'lib/pago/v2026_04/models.rb', line 1369 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
1329 1330 1331 |
# File 'lib/pago/v2026_04/models.rb', line 1329 def @timestamp end |
Class Method Details
.from_json(data) ⇒ BalanceOrderEvent?
1413 1414 1415 1416 1417 1418 1419 1420 1421 1422 1423 1424 1425 1426 1427 1428 1429 1430 1431 1432 1433 1434 1435 1436 1437 |
# File 'lib/pago/v2026_04/models.rb', line 1413 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::BalanceOrderMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |