Class: Pago::V2026_04::Models::BenefitCustomUpdate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ metadata: "metadata", description: "description", visibility: "visibility", type: "type", properties: "properties" }.freeze
- REQUIRED_KEYS =
["type"].freeze
Instance Attribute Summary collapse
-
#description ⇒ String?
readonly
The description of the benefit.
-
#metadata ⇒ Hash{String => String, Integer, Float, Boolean}
readonly
Key-value object allowing you to store additional information.
- #properties ⇒ Models::BenefitCustomProperties? readonly
- #type ⇒ String readonly
-
#visibility ⇒ String?
readonly
The visibility of the benefit in the customer portal.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: ::Pago::UNSET, description: ::Pago::UNSET, visibility: ::Pago::UNSET, type:, properties: ::Pago::UNSET) ⇒ BenefitCustomUpdate
constructor
A new instance of BenefitCustomUpdate.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(metadata: ::Pago::UNSET, description: ::Pago::UNSET, visibility: ::Pago::UNSET, type:, properties: ::Pago::UNSET) ⇒ BenefitCustomUpdate
Returns a new instance of BenefitCustomUpdate.
2430 2431 2432 2433 2434 2435 2436 2437 2438 2439 2440 2441 2442 2443 |
# File 'lib/pago/v2026_04/models.rb', line 2430 def initialize( metadata: ::Pago::UNSET, description: ::Pago::UNSET, visibility: ::Pago::UNSET, type:, properties: ::Pago::UNSET ) super() assign(:metadata, ) assign(:description, description) assign(:visibility, visibility) assign(:type, type) assign(:properties, properties) end |
Instance Attribute Details
#description ⇒ String? (readonly)
The description of the benefit. Will be displayed on products having this benefit.
2418 2419 2420 |
# File 'lib/pago/v2026_04/models.rb', line 2418 def description @description end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
Key-value object allowing you to store additional information.
The key must be a string with a maximum length of 40 characters. The value must be either:
- A string with a maximum length of 500 characters
- An integer
- A floating-point number
- A boolean
You can store up to 50 key-value pairs.
2414 2415 2416 |
# File 'lib/pago/v2026_04/models.rb', line 2414 def @metadata end |
#properties ⇒ Models::BenefitCustomProperties? (readonly)
2428 2429 2430 |
# File 'lib/pago/v2026_04/models.rb', line 2428 def properties @properties end |
#type ⇒ String (readonly)
2425 2426 2427 |
# File 'lib/pago/v2026_04/models.rb', line 2425 def type @type end |
#visibility ⇒ String? (readonly)
The visibility of the benefit in the customer portal.
2422 2423 2424 |
# File 'lib/pago/v2026_04/models.rb', line 2422 def visibility @visibility end |
Class Method Details
.from_json(data) ⇒ BenefitCustomUpdate?
2447 2448 2449 2450 2451 2452 2453 2454 2455 2456 2457 2458 2459 2460 2461 2462 |
# File 'lib/pago/v2026_04/models.rb', line 2447 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), description: (data.key?("description") ? data["description"] : ::Pago::UNSET), visibility: (data.key?("visibility") ? data["visibility"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), properties: (data.key?("properties") ? Models::BenefitCustomProperties.from_json(data["properties"]) : ::Pago::UNSET) ), data ) end |