Class: Pago::V2026_04::Models::BenefitMeterCreditUpdate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Constant Summary collapse
- JSON_KEYS =
{ metadata: "metadata", description: "description", visibility: "visibility", type: "type", properties: "properties" }.freeze
- REQUIRED_KEYS =
["type"].freeze
Instance Attribute Summary collapse
-
#description ⇒ String?
readonly
The description of the benefit.
-
#metadata ⇒ Hash{String => String, Integer, Float, Boolean}
readonly
Key-value object allowing you to store additional information.
- #properties ⇒ Models::BenefitMeterCreditCreateProperties? readonly
- #type ⇒ String readonly
-
#visibility ⇒ String?
readonly
The visibility of the benefit in the customer portal.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(metadata: ::Pago::UNSET, description: ::Pago::UNSET, visibility: ::Pago::UNSET, type:, properties: ::Pago::UNSET) ⇒ BenefitMeterCreditUpdate
constructor
A new instance of BenefitMeterCreditUpdate.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(metadata: ::Pago::UNSET, description: ::Pago::UNSET, visibility: ::Pago::UNSET, type:, properties: ::Pago::UNSET) ⇒ BenefitMeterCreditUpdate
Returns a new instance of BenefitMeterCreditUpdate.
7807 7808 7809 7810 7811 7812 7813 7814 7815 7816 7817 7818 7819 7820 |
# File 'lib/pago/v2026_04/models.rb', line 7807 def initialize( metadata: ::Pago::UNSET, description: ::Pago::UNSET, visibility: ::Pago::UNSET, type:, properties: ::Pago::UNSET ) super() assign(:metadata, ) assign(:description, description) assign(:visibility, visibility) assign(:type, type) assign(:properties, properties) end |
Instance Attribute Details
#description ⇒ String? (readonly)
The description of the benefit. Will be displayed on products having this benefit.
7795 7796 7797 |
# File 'lib/pago/v2026_04/models.rb', line 7795 def description @description end |
#metadata ⇒ Hash{String => String, Integer, Float, Boolean} (readonly)
Key-value object allowing you to store additional information.
The key must be a string with a maximum length of 40 characters. The value must be either:
- A string with a maximum length of 500 characters
- An integer
- A floating-point number
- A boolean
You can store up to 50 key-value pairs.
7791 7792 7793 |
# File 'lib/pago/v2026_04/models.rb', line 7791 def @metadata end |
#properties ⇒ Models::BenefitMeterCreditCreateProperties? (readonly)
7805 7806 7807 |
# File 'lib/pago/v2026_04/models.rb', line 7805 def properties @properties end |
#type ⇒ String (readonly)
7802 7803 7804 |
# File 'lib/pago/v2026_04/models.rb', line 7802 def type @type end |
#visibility ⇒ String? (readonly)
The visibility of the benefit in the customer portal.
7799 7800 7801 |
# File 'lib/pago/v2026_04/models.rb', line 7799 def visibility @visibility end |
Class Method Details
.from_json(data) ⇒ BenefitMeterCreditUpdate?
7824 7825 7826 7827 7828 7829 7830 7831 7832 7833 7834 7835 7836 7837 7838 7839 |
# File 'lib/pago/v2026_04/models.rb', line 7824 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( metadata: (data.key?("metadata") ? data["metadata"] : ::Pago::UNSET), description: (data.key?("description") ? data["description"] : ::Pago::UNSET), visibility: (data.key?("visibility") ? data["visibility"] : ::Pago::UNSET), type: (data.key?("type") ? data["type"] : ::Pago::UNSET), properties: (data.key?("properties") ? Models::BenefitMeterCreditCreateProperties.from_json(data["properties"]) : ::Pago::UNSET) ), data ) end |