Class: Pago::V2026_04::Models::BenefitUpdatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a benefit is updated.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::BenefitGrantMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ BenefitUpdatedEvent
constructor
A new instance of BenefitUpdatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ BenefitUpdatedEvent
Returns a new instance of BenefitUpdatedEvent.
8779 8780 8781 8782 8783 8784 8785 8786 8787 8788 8789 8790 8791 8792 8793 8794 8795 8796 8797 8798 8799 8800 8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 |
# File 'lib/pago/v2026_04/models.rb', line 8779 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
8758 8759 8760 |
# File 'lib/pago/v2026_04/models.rb', line 8758 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
8742 8743 8744 |
# File 'lib/pago/v2026_04/models.rb', line 8742 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
8738 8739 8740 |
# File 'lib/pago/v2026_04/models.rb', line 8738 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
8746 8747 8748 |
# File 'lib/pago/v2026_04/models.rb', line 8746 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
8754 8755 8756 |
# File 'lib/pago/v2026_04/models.rb', line 8754 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
8726 8727 8728 |
# File 'lib/pago/v2026_04/models.rb', line 8726 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
8766 8767 8768 |
# File 'lib/pago/v2026_04/models.rb', line 8766 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
8750 8751 8752 |
# File 'lib/pago/v2026_04/models.rb', line 8750 def member_id @member_id end |
#metadata ⇒ Models::BenefitGrantMetadata (readonly)
8777 8778 8779 |
# File 'lib/pago/v2026_04/models.rb', line 8777 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
8774 8775 8776 |
# File 'lib/pago/v2026_04/models.rb', line 8774 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
8734 8735 8736 |
# File 'lib/pago/v2026_04/models.rb', line 8734 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
8762 8763 8764 |
# File 'lib/pago/v2026_04/models.rb', line 8762 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
8770 8771 8772 |
# File 'lib/pago/v2026_04/models.rb', line 8770 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
8730 8731 8732 |
# File 'lib/pago/v2026_04/models.rb', line 8730 def @timestamp end |
Class Method Details
.from_json(data) ⇒ BenefitUpdatedEvent?
8814 8815 8816 8817 8818 8819 8820 8821 8822 8823 8824 8825 8826 8827 8828 8829 8830 8831 8832 8833 8834 8835 8836 8837 8838 |
# File 'lib/pago/v2026_04/models.rb', line 8814 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::BenefitGrantMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |