Class: Pago::V2026_04::Models::CheckoutCreatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a checkout is created.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::CheckoutCreatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CheckoutCreatedEvent
constructor
A new instance of CheckoutCreatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CheckoutCreatedEvent
Returns a new instance of CheckoutCreatedEvent.
10128 10129 10130 10131 10132 10133 10134 10135 10136 10137 10138 10139 10140 10141 10142 10143 10144 10145 10146 10147 10148 10149 10150 10151 10152 10153 10154 10155 10156 10157 10158 10159 |
# File 'lib/pago/v2026_04/models.rb', line 10128 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
10107 10108 10109 |
# File 'lib/pago/v2026_04/models.rb', line 10107 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
10091 10092 10093 |
# File 'lib/pago/v2026_04/models.rb', line 10091 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
10087 10088 10089 |
# File 'lib/pago/v2026_04/models.rb', line 10087 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
10095 10096 10097 |
# File 'lib/pago/v2026_04/models.rb', line 10095 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
10103 10104 10105 |
# File 'lib/pago/v2026_04/models.rb', line 10103 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
10075 10076 10077 |
# File 'lib/pago/v2026_04/models.rb', line 10075 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
10115 10116 10117 |
# File 'lib/pago/v2026_04/models.rb', line 10115 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
10099 10100 10101 |
# File 'lib/pago/v2026_04/models.rb', line 10099 def member_id @member_id end |
#metadata ⇒ Models::CheckoutCreatedMetadata (readonly)
10126 10127 10128 |
# File 'lib/pago/v2026_04/models.rb', line 10126 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
10123 10124 10125 |
# File 'lib/pago/v2026_04/models.rb', line 10123 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
10083 10084 10085 |
# File 'lib/pago/v2026_04/models.rb', line 10083 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
10111 10112 10113 |
# File 'lib/pago/v2026_04/models.rb', line 10111 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
10119 10120 10121 |
# File 'lib/pago/v2026_04/models.rb', line 10119 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
10079 10080 10081 |
# File 'lib/pago/v2026_04/models.rb', line 10079 def @timestamp end |
Class Method Details
.from_json(data) ⇒ CheckoutCreatedEvent?
10163 10164 10165 10166 10167 10168 10169 10170 10171 10172 10173 10174 10175 10176 10177 10178 10179 10180 10181 10182 10183 10184 10185 10186 10187 |
# File 'lib/pago/v2026_04/models.rb', line 10163 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::CheckoutCreatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |