Class: Pago::V2026_04::Models::CustomerCreatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a customer is created.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::CustomerCreatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CustomerCreatedEvent
constructor
A new instance of CustomerCreatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CustomerCreatedEvent
Returns a new instance of CustomerCreatedEvent.
16283 16284 16285 16286 16287 16288 16289 16290 16291 16292 16293 16294 16295 16296 16297 16298 16299 16300 16301 16302 16303 16304 16305 16306 16307 16308 16309 16310 16311 16312 16313 16314 |
# File 'lib/pago/v2026_04/models.rb', line 16283 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
16262 16263 16264 |
# File 'lib/pago/v2026_04/models.rb', line 16262 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
16246 16247 16248 |
# File 'lib/pago/v2026_04/models.rb', line 16246 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
16242 16243 16244 |
# File 'lib/pago/v2026_04/models.rb', line 16242 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
16250 16251 16252 |
# File 'lib/pago/v2026_04/models.rb', line 16250 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
16258 16259 16260 |
# File 'lib/pago/v2026_04/models.rb', line 16258 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
16230 16231 16232 |
# File 'lib/pago/v2026_04/models.rb', line 16230 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
16270 16271 16272 |
# File 'lib/pago/v2026_04/models.rb', line 16270 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
16254 16255 16256 |
# File 'lib/pago/v2026_04/models.rb', line 16254 def member_id @member_id end |
#metadata ⇒ Models::CustomerCreatedMetadata (readonly)
16281 16282 16283 |
# File 'lib/pago/v2026_04/models.rb', line 16281 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
16278 16279 16280 |
# File 'lib/pago/v2026_04/models.rb', line 16278 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
16238 16239 16240 |
# File 'lib/pago/v2026_04/models.rb', line 16238 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
16266 16267 16268 |
# File 'lib/pago/v2026_04/models.rb', line 16266 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
16274 16275 16276 |
# File 'lib/pago/v2026_04/models.rb', line 16274 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
16234 16235 16236 |
# File 'lib/pago/v2026_04/models.rb', line 16234 def @timestamp end |
Class Method Details
.from_json(data) ⇒ CustomerCreatedEvent?
16318 16319 16320 16321 16322 16323 16324 16325 16326 16327 16328 16329 16330 16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 16342 |
# File 'lib/pago/v2026_04/models.rb', line 16318 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::CustomerCreatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |