Class: Pago::V2026_04::Models::CustomerDeletedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a customer is deleted.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::CustomerDeletedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CustomerDeletedEvent
constructor
A new instance of CustomerDeletedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CustomerDeletedEvent
Returns a new instance of CustomerDeletedEvent.
16665 16666 16667 16668 16669 16670 16671 16672 16673 16674 16675 16676 16677 16678 16679 16680 16681 16682 16683 16684 16685 16686 16687 16688 16689 16690 16691 16692 16693 16694 16695 16696 |
# File 'lib/pago/v2026_04/models.rb', line 16665 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
16644 16645 16646 |
# File 'lib/pago/v2026_04/models.rb', line 16644 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
16628 16629 16630 |
# File 'lib/pago/v2026_04/models.rb', line 16628 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
16624 16625 16626 |
# File 'lib/pago/v2026_04/models.rb', line 16624 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
16632 16633 16634 |
# File 'lib/pago/v2026_04/models.rb', line 16632 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
16640 16641 16642 |
# File 'lib/pago/v2026_04/models.rb', line 16640 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
16612 16613 16614 |
# File 'lib/pago/v2026_04/models.rb', line 16612 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
16652 16653 16654 |
# File 'lib/pago/v2026_04/models.rb', line 16652 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
16636 16637 16638 |
# File 'lib/pago/v2026_04/models.rb', line 16636 def member_id @member_id end |
#metadata ⇒ Models::CustomerDeletedMetadata (readonly)
16663 16664 16665 |
# File 'lib/pago/v2026_04/models.rb', line 16663 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
16660 16661 16662 |
# File 'lib/pago/v2026_04/models.rb', line 16660 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
16620 16621 16622 |
# File 'lib/pago/v2026_04/models.rb', line 16620 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
16648 16649 16650 |
# File 'lib/pago/v2026_04/models.rb', line 16648 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
16656 16657 16658 |
# File 'lib/pago/v2026_04/models.rb', line 16656 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
16616 16617 16618 |
# File 'lib/pago/v2026_04/models.rb', line 16616 def @timestamp end |
Class Method Details
.from_json(data) ⇒ CustomerDeletedEvent?
16700 16701 16702 16703 16704 16705 16706 16707 16708 16709 16710 16711 16712 16713 16714 16715 16716 16717 16718 16719 16720 16721 16722 16723 16724 |
# File 'lib/pago/v2026_04/models.rb', line 16700 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::CustomerDeletedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |