Class: Pago::V2026_04::Models::CustomerOrderConfirmPayment
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
Schema to confirm a retry payment using either a saved payment method or a new confirmation token.
Constant Summary collapse
- JSON_KEYS =
{ confirmation_token_id: "confirmation_token_id", payment_method_id: "payment_method_id", payment_processor: "payment_processor" }.freeze
- REQUIRED_KEYS =
[].freeze
Instance Attribute Summary collapse
-
#confirmation_token_id ⇒ String?
readonly
ID of the Stripe confirmation token for new payment methods.
-
#payment_method_id ⇒ String?
readonly
ID of an existing saved payment method.
- #payment_processor ⇒ String readonly
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(confirmation_token_id: ::Pago::UNSET, payment_method_id: ::Pago::UNSET, payment_processor: ::Pago::UNSET) ⇒ CustomerOrderConfirmPayment
constructor
A new instance of CustomerOrderConfirmPayment.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(confirmation_token_id: ::Pago::UNSET, payment_method_id: ::Pago::UNSET, payment_processor: ::Pago::UNSET) ⇒ CustomerOrderConfirmPayment
Returns a new instance of CustomerOrderConfirmPayment.
17592 17593 17594 17595 17596 17597 17598 17599 17600 17601 |
# File 'lib/pago/v2026_04/models.rb', line 17592 def initialize( confirmation_token_id: ::Pago::UNSET, payment_method_id: ::Pago::UNSET, payment_processor: ::Pago::UNSET ) super() assign(:confirmation_token_id, confirmation_token_id) assign(:payment_method_id, payment_method_id) assign(:payment_processor, payment_processor) end |
Instance Attribute Details
#confirmation_token_id ⇒ String? (readonly)
ID of the Stripe confirmation token for new payment methods.
17583 17584 17585 |
# File 'lib/pago/v2026_04/models.rb', line 17583 def confirmation_token_id @confirmation_token_id end |
#payment_method_id ⇒ String? (readonly)
ID of an existing saved payment method.
17587 17588 17589 |
# File 'lib/pago/v2026_04/models.rb', line 17587 def payment_method_id @payment_method_id end |
#payment_processor ⇒ String (readonly)
17590 17591 17592 |
# File 'lib/pago/v2026_04/models.rb', line 17590 def payment_processor @payment_processor end |
Class Method Details
.from_json(data) ⇒ CustomerOrderConfirmPayment?
17605 17606 17607 17608 17609 17610 17611 17612 17613 17614 17615 17616 17617 17618 |
# File 'lib/pago/v2026_04/models.rb', line 17605 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( confirmation_token_id: (data.key?("confirmation_token_id") ? data["confirmation_token_id"] : ::Pago::UNSET), payment_method_id: (data.key?("payment_method_id") ? data["payment_method_id"] : ::Pago::UNSET), payment_processor: (data.key?("payment_processor") ? data["payment_processor"] : ::Pago::UNSET) ), data ) end |