Class: Pago::V2026_04::Models::CustomerUpdatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a customer is updated.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::CustomerUpdatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CustomerUpdatedEvent
constructor
A new instance of CustomerUpdatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ CustomerUpdatedEvent
Returns a new instance of CustomerUpdatedEvent.
22087 22088 22089 22090 22091 22092 22093 22094 22095 22096 22097 22098 22099 22100 22101 22102 22103 22104 22105 22106 22107 22108 22109 22110 22111 22112 22113 22114 22115 22116 22117 22118 |
# File 'lib/pago/v2026_04/models.rb', line 22087 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
22066 22067 22068 |
# File 'lib/pago/v2026_04/models.rb', line 22066 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
22050 22051 22052 |
# File 'lib/pago/v2026_04/models.rb', line 22050 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
22046 22047 22048 |
# File 'lib/pago/v2026_04/models.rb', line 22046 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
22054 22055 22056 |
# File 'lib/pago/v2026_04/models.rb', line 22054 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
22062 22063 22064 |
# File 'lib/pago/v2026_04/models.rb', line 22062 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
22034 22035 22036 |
# File 'lib/pago/v2026_04/models.rb', line 22034 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
22074 22075 22076 |
# File 'lib/pago/v2026_04/models.rb', line 22074 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
22058 22059 22060 |
# File 'lib/pago/v2026_04/models.rb', line 22058 def member_id @member_id end |
#metadata ⇒ Models::CustomerUpdatedMetadata (readonly)
22085 22086 22087 |
# File 'lib/pago/v2026_04/models.rb', line 22085 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
22082 22083 22084 |
# File 'lib/pago/v2026_04/models.rb', line 22082 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
22042 22043 22044 |
# File 'lib/pago/v2026_04/models.rb', line 22042 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
22070 22071 22072 |
# File 'lib/pago/v2026_04/models.rb', line 22070 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
22078 22079 22080 |
# File 'lib/pago/v2026_04/models.rb', line 22078 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
22038 22039 22040 |
# File 'lib/pago/v2026_04/models.rb', line 22038 def @timestamp end |
Class Method Details
.from_json(data) ⇒ CustomerUpdatedEvent?
22122 22123 22124 22125 22126 22127 22128 22129 22130 22131 22132 22133 22134 22135 22136 22137 22138 22139 22140 22141 22142 22143 22144 22145 22146 |
# File 'lib/pago/v2026_04/models.rb', line 22122 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::CustomerUpdatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |