Class: Pago::V2026_04::Models::MeterCreditEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when credits are added to a customer meter.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::MeterCreditedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ MeterCreditEvent
constructor
A new instance of MeterCreditEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ MeterCreditEvent
Returns a new instance of MeterCreditEvent.
29295 29296 29297 29298 29299 29300 29301 29302 29303 29304 29305 29306 29307 29308 29309 29310 29311 29312 29313 29314 29315 29316 29317 29318 29319 29320 29321 29322 29323 29324 29325 29326 |
# File 'lib/pago/v2026_04/models.rb', line 29295 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
29274 29275 29276 |
# File 'lib/pago/v2026_04/models.rb', line 29274 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
29258 29259 29260 |
# File 'lib/pago/v2026_04/models.rb', line 29258 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
29254 29255 29256 |
# File 'lib/pago/v2026_04/models.rb', line 29254 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
29262 29263 29264 |
# File 'lib/pago/v2026_04/models.rb', line 29262 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
29270 29271 29272 |
# File 'lib/pago/v2026_04/models.rb', line 29270 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
29242 29243 29244 |
# File 'lib/pago/v2026_04/models.rb', line 29242 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
29282 29283 29284 |
# File 'lib/pago/v2026_04/models.rb', line 29282 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
29266 29267 29268 |
# File 'lib/pago/v2026_04/models.rb', line 29266 def member_id @member_id end |
#metadata ⇒ Models::MeterCreditedMetadata (readonly)
29293 29294 29295 |
# File 'lib/pago/v2026_04/models.rb', line 29293 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
29290 29291 29292 |
# File 'lib/pago/v2026_04/models.rb', line 29290 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
29250 29251 29252 |
# File 'lib/pago/v2026_04/models.rb', line 29250 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
29278 29279 29280 |
# File 'lib/pago/v2026_04/models.rb', line 29278 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
29286 29287 29288 |
# File 'lib/pago/v2026_04/models.rb', line 29286 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
29246 29247 29248 |
# File 'lib/pago/v2026_04/models.rb', line 29246 def @timestamp end |
Class Method Details
.from_json(data) ⇒ MeterCreditEvent?
29330 29331 29332 29333 29334 29335 29336 29337 29338 29339 29340 29341 29342 29343 29344 29345 29346 29347 29348 29349 29350 29351 29352 29353 29354 |
# File 'lib/pago/v2026_04/models.rb', line 29330 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::MeterCreditedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |