Class: Pago::V2026_04::Models::OrderRefundedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when an order is refunded.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::OrderRefundedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ OrderRefundedEvent
constructor
A new instance of OrderRefundedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ OrderRefundedEvent
Returns a new instance of OrderRefundedEvent.
33228 33229 33230 33231 33232 33233 33234 33235 33236 33237 33238 33239 33240 33241 33242 33243 33244 33245 33246 33247 33248 33249 33250 33251 33252 33253 33254 33255 33256 33257 33258 33259 |
# File 'lib/pago/v2026_04/models.rb', line 33228 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
33207 33208 33209 |
# File 'lib/pago/v2026_04/models.rb', line 33207 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
33191 33192 33193 |
# File 'lib/pago/v2026_04/models.rb', line 33191 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
33187 33188 33189 |
# File 'lib/pago/v2026_04/models.rb', line 33187 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
33195 33196 33197 |
# File 'lib/pago/v2026_04/models.rb', line 33195 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
33203 33204 33205 |
# File 'lib/pago/v2026_04/models.rb', line 33203 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
33175 33176 33177 |
# File 'lib/pago/v2026_04/models.rb', line 33175 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
33215 33216 33217 |
# File 'lib/pago/v2026_04/models.rb', line 33215 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
33199 33200 33201 |
# File 'lib/pago/v2026_04/models.rb', line 33199 def member_id @member_id end |
#metadata ⇒ Models::OrderRefundedMetadata (readonly)
33226 33227 33228 |
# File 'lib/pago/v2026_04/models.rb', line 33226 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
33223 33224 33225 |
# File 'lib/pago/v2026_04/models.rb', line 33223 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
33183 33184 33185 |
# File 'lib/pago/v2026_04/models.rb', line 33183 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
33211 33212 33213 |
# File 'lib/pago/v2026_04/models.rb', line 33211 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
33219 33220 33221 |
# File 'lib/pago/v2026_04/models.rb', line 33219 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
33179 33180 33181 |
# File 'lib/pago/v2026_04/models.rb', line 33179 def @timestamp end |
Class Method Details
.from_json(data) ⇒ OrderRefundedEvent?
33263 33264 33265 33266 33267 33268 33269 33270 33271 33272 33273 33274 33275 33276 33277 33278 33279 33280 33281 33282 33283 33284 33285 33286 33287 |
# File 'lib/pago/v2026_04/models.rb', line 33263 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::OrderRefundedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |