Class: Pago::V2026_04::Models::OrderVoidedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when an order is voided.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::OrderVoidedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ OrderVoidedEvent
constructor
A new instance of OrderVoidedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ OrderVoidedEvent
Returns a new instance of OrderVoidedEvent.
33720 33721 33722 33723 33724 33725 33726 33727 33728 33729 33730 33731 33732 33733 33734 33735 33736 33737 33738 33739 33740 33741 33742 33743 33744 33745 33746 33747 33748 33749 33750 33751 |
# File 'lib/pago/v2026_04/models.rb', line 33720 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
33699 33700 33701 |
# File 'lib/pago/v2026_04/models.rb', line 33699 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
33683 33684 33685 |
# File 'lib/pago/v2026_04/models.rb', line 33683 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
33679 33680 33681 |
# File 'lib/pago/v2026_04/models.rb', line 33679 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
33687 33688 33689 |
# File 'lib/pago/v2026_04/models.rb', line 33687 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
33695 33696 33697 |
# File 'lib/pago/v2026_04/models.rb', line 33695 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
33667 33668 33669 |
# File 'lib/pago/v2026_04/models.rb', line 33667 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
33707 33708 33709 |
# File 'lib/pago/v2026_04/models.rb', line 33707 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
33691 33692 33693 |
# File 'lib/pago/v2026_04/models.rb', line 33691 def member_id @member_id end |
#metadata ⇒ Models::OrderVoidedMetadata (readonly)
33718 33719 33720 |
# File 'lib/pago/v2026_04/models.rb', line 33718 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
33715 33716 33717 |
# File 'lib/pago/v2026_04/models.rb', line 33715 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
33675 33676 33677 |
# File 'lib/pago/v2026_04/models.rb', line 33675 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
33703 33704 33705 |
# File 'lib/pago/v2026_04/models.rb', line 33703 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
33711 33712 33713 |
# File 'lib/pago/v2026_04/models.rb', line 33711 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
33671 33672 33673 |
# File 'lib/pago/v2026_04/models.rb', line 33671 def @timestamp end |
Class Method Details
.from_json(data) ⇒ OrderVoidedEvent?
33755 33756 33757 33758 33759 33760 33761 33762 33763 33764 33765 33766 33767 33768 33769 33770 33771 33772 33773 33774 33775 33776 33777 33778 33779 |
# File 'lib/pago/v2026_04/models.rb', line 33755 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::OrderVoidedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |