Class: Pago::V2026_04::Models::OrganizationFeatureSettingsUpdate
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
Feature settings that organizations can update themselves.
Other feature settings are managed by Pago staff: they're ignored if provided and keep their current value.
Constant Summary collapse
- JSON_KEYS =
{ seat_based_pricing_enabled: "seat_based_pricing_enabled", member_model_enabled: "member_model_enabled", checkout_localization_enabled: "checkout_localization_enabled", overview_metrics: "overview_metrics" }.freeze
- REQUIRED_KEYS =
[].freeze
Instance Attribute Summary collapse
-
#checkout_localization_enabled ⇒ Boolean
readonly
If this organization has checkout localization enabled.
-
#member_model_enabled ⇒ Boolean
readonly
If this organization has the Member model enabled.
-
#overview_metrics ⇒ Array<String>?
readonly
Ordered list of metric slugs shown on the dashboard overview.
-
#seat_based_pricing_enabled ⇒ Boolean
readonly
If this organization has seat-based pricing enabled.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(seat_based_pricing_enabled: ::Pago::UNSET, member_model_enabled: ::Pago::UNSET, checkout_localization_enabled: ::Pago::UNSET, overview_metrics: ::Pago::UNSET) ⇒ OrganizationFeatureSettingsUpdate
constructor
A new instance of OrganizationFeatureSettingsUpdate.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(seat_based_pricing_enabled: ::Pago::UNSET, member_model_enabled: ::Pago::UNSET, checkout_localization_enabled: ::Pago::UNSET, overview_metrics: ::Pago::UNSET) ⇒ OrganizationFeatureSettingsUpdate
Returns a new instance of OrganizationFeatureSettingsUpdate.
34953 34954 34955 34956 34957 34958 34959 34960 34961 34962 34963 34964 |
# File 'lib/pago/v2026_04/models.rb', line 34953 def initialize( seat_based_pricing_enabled: ::Pago::UNSET, member_model_enabled: ::Pago::UNSET, checkout_localization_enabled: ::Pago::UNSET, overview_metrics: ::Pago::UNSET ) super() assign(:seat_based_pricing_enabled, seat_based_pricing_enabled) assign(:member_model_enabled, member_model_enabled) assign(:checkout_localization_enabled, checkout_localization_enabled) assign(:overview_metrics, overview_metrics) end |
Instance Attribute Details
#checkout_localization_enabled ⇒ Boolean (readonly)
If this organization has checkout localization enabled
34947 34948 34949 |
# File 'lib/pago/v2026_04/models.rb', line 34947 def checkout_localization_enabled @checkout_localization_enabled end |
#member_model_enabled ⇒ Boolean (readonly)
If this organization has the Member model enabled
34943 34944 34945 |
# File 'lib/pago/v2026_04/models.rb', line 34943 def member_model_enabled @member_model_enabled end |
#overview_metrics ⇒ Array<String>? (readonly)
Ordered list of metric slugs shown on the dashboard overview.
34951 34952 34953 |
# File 'lib/pago/v2026_04/models.rb', line 34951 def overview_metrics @overview_metrics end |
#seat_based_pricing_enabled ⇒ Boolean (readonly)
If this organization has seat-based pricing enabled
34939 34940 34941 |
# File 'lib/pago/v2026_04/models.rb', line 34939 def seat_based_pricing_enabled @seat_based_pricing_enabled end |
Class Method Details
.from_json(data) ⇒ OrganizationFeatureSettingsUpdate?
34968 34969 34970 34971 34972 34973 34974 34975 34976 34977 34978 34979 34980 34981 34982 |
# File 'lib/pago/v2026_04/models.rb', line 34968 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( seat_based_pricing_enabled: (data.key?("seat_based_pricing_enabled") ? data["seat_based_pricing_enabled"] : ::Pago::UNSET), member_model_enabled: (data.key?("member_model_enabled") ? data["member_model_enabled"] : ::Pago::UNSET), checkout_localization_enabled: (data.key?("checkout_localization_enabled") ? data["checkout_localization_enabled"] : ::Pago::UNSET), overview_metrics: (data.key?("overview_metrics") ? data["overview_metrics"] : ::Pago::UNSET) ), data ) end |