Class: Pago::V2026_04::Models::SubscriptionBillingPeriodUpdatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a subscription billing period is updated.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionBillingPeriodUpdatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionBillingPeriodUpdatedEvent
constructor
A new instance of SubscriptionBillingPeriodUpdatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionBillingPeriodUpdatedEvent
Returns a new instance of SubscriptionBillingPeriodUpdatedEvent.
39638 39639 39640 39641 39642 39643 39644 39645 39646 39647 39648 39649 39650 39651 39652 39653 39654 39655 39656 39657 39658 39659 39660 39661 39662 39663 39664 39665 39666 39667 39668 39669 |
# File 'lib/pago/v2026_04/models.rb', line 39638 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
39617 39618 39619 |
# File 'lib/pago/v2026_04/models.rb', line 39617 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
39601 39602 39603 |
# File 'lib/pago/v2026_04/models.rb', line 39601 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
39597 39598 39599 |
# File 'lib/pago/v2026_04/models.rb', line 39597 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
39605 39606 39607 |
# File 'lib/pago/v2026_04/models.rb', line 39605 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
39613 39614 39615 |
# File 'lib/pago/v2026_04/models.rb', line 39613 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
39585 39586 39587 |
# File 'lib/pago/v2026_04/models.rb', line 39585 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
39625 39626 39627 |
# File 'lib/pago/v2026_04/models.rb', line 39625 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
39609 39610 39611 |
# File 'lib/pago/v2026_04/models.rb', line 39609 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionBillingPeriodUpdatedMetadata (readonly)
39636 39637 39638 |
# File 'lib/pago/v2026_04/models.rb', line 39636 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
39633 39634 39635 |
# File 'lib/pago/v2026_04/models.rb', line 39633 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
39593 39594 39595 |
# File 'lib/pago/v2026_04/models.rb', line 39593 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
39621 39622 39623 |
# File 'lib/pago/v2026_04/models.rb', line 39621 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
39629 39630 39631 |
# File 'lib/pago/v2026_04/models.rb', line 39629 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
39589 39590 39591 |
# File 'lib/pago/v2026_04/models.rb', line 39589 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionBillingPeriodUpdatedEvent?
39673 39674 39675 39676 39677 39678 39679 39680 39681 39682 39683 39684 39685 39686 39687 39688 39689 39690 39691 39692 39693 39694 39695 39696 39697 |
# File 'lib/pago/v2026_04/models.rb', line 39673 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionBillingPeriodUpdatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |