Class: Pago::V2026_04::Models::SubscriptionCanceledEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a subscription is canceled.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionCanceledMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionCanceledEvent
constructor
A new instance of SubscriptionCanceledEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionCanceledEvent
Returns a new instance of SubscriptionCanceledEvent.
39896 39897 39898 39899 39900 39901 39902 39903 39904 39905 39906 39907 39908 39909 39910 39911 39912 39913 39914 39915 39916 39917 39918 39919 39920 39921 39922 39923 39924 39925 39926 39927 |
# File 'lib/pago/v2026_04/models.rb', line 39896 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
39875 39876 39877 |
# File 'lib/pago/v2026_04/models.rb', line 39875 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
39859 39860 39861 |
# File 'lib/pago/v2026_04/models.rb', line 39859 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
39855 39856 39857 |
# File 'lib/pago/v2026_04/models.rb', line 39855 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
39863 39864 39865 |
# File 'lib/pago/v2026_04/models.rb', line 39863 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
39871 39872 39873 |
# File 'lib/pago/v2026_04/models.rb', line 39871 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
39843 39844 39845 |
# File 'lib/pago/v2026_04/models.rb', line 39843 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
39883 39884 39885 |
# File 'lib/pago/v2026_04/models.rb', line 39883 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
39867 39868 39869 |
# File 'lib/pago/v2026_04/models.rb', line 39867 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionCanceledMetadata (readonly)
39894 39895 39896 |
# File 'lib/pago/v2026_04/models.rb', line 39894 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
39891 39892 39893 |
# File 'lib/pago/v2026_04/models.rb', line 39891 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
39851 39852 39853 |
# File 'lib/pago/v2026_04/models.rb', line 39851 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
39879 39880 39881 |
# File 'lib/pago/v2026_04/models.rb', line 39879 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
39887 39888 39889 |
# File 'lib/pago/v2026_04/models.rb', line 39887 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
39847 39848 39849 |
# File 'lib/pago/v2026_04/models.rb', line 39847 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionCanceledEvent?
39931 39932 39933 39934 39935 39936 39937 39938 39939 39940 39941 39942 39943 39944 39945 39946 39947 39948 39949 39950 39951 39952 39953 39954 39955 |
# File 'lib/pago/v2026_04/models.rb', line 39931 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionCanceledMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |