Class: Pago::V2026_04::Models::SubscriptionPastDueEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a subscription becomes past due.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionPastDueMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionPastDueEvent
constructor
A new instance of SubscriptionPastDueEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionPastDueEvent
Returns a new instance of SubscriptionPastDueEvent.
40953 40954 40955 40956 40957 40958 40959 40960 40961 40962 40963 40964 40965 40966 40967 40968 40969 40970 40971 40972 40973 40974 40975 40976 40977 40978 40979 40980 40981 40982 40983 40984 |
# File 'lib/pago/v2026_04/models.rb', line 40953 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
40932 40933 40934 |
# File 'lib/pago/v2026_04/models.rb', line 40932 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
40916 40917 40918 |
# File 'lib/pago/v2026_04/models.rb', line 40916 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
40912 40913 40914 |
# File 'lib/pago/v2026_04/models.rb', line 40912 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
40920 40921 40922 |
# File 'lib/pago/v2026_04/models.rb', line 40920 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
40928 40929 40930 |
# File 'lib/pago/v2026_04/models.rb', line 40928 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
40900 40901 40902 |
# File 'lib/pago/v2026_04/models.rb', line 40900 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
40940 40941 40942 |
# File 'lib/pago/v2026_04/models.rb', line 40940 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
40924 40925 40926 |
# File 'lib/pago/v2026_04/models.rb', line 40924 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionPastDueMetadata (readonly)
40951 40952 40953 |
# File 'lib/pago/v2026_04/models.rb', line 40951 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
40948 40949 40950 |
# File 'lib/pago/v2026_04/models.rb', line 40948 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
40908 40909 40910 |
# File 'lib/pago/v2026_04/models.rb', line 40908 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
40936 40937 40938 |
# File 'lib/pago/v2026_04/models.rb', line 40936 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
40944 40945 40946 |
# File 'lib/pago/v2026_04/models.rb', line 40944 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
40904 40905 40906 |
# File 'lib/pago/v2026_04/models.rb', line 40904 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionPastDueEvent?
40988 40989 40990 40991 40992 40993 40994 40995 40996 40997 40998 40999 41000 41001 41002 41003 41004 41005 41006 41007 41008 41009 41010 41011 41012 |
# File 'lib/pago/v2026_04/models.rb', line 40988 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionPastDueMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |