Class: Pago::V2026_04::Models::SubscriptionReactivatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a past due subscription is recovered.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionReactivatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionReactivatedEvent
constructor
A new instance of SubscriptionReactivatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionReactivatedEvent
Returns a new instance of SubscriptionReactivatedEvent.
41612 41613 41614 41615 41616 41617 41618 41619 41620 41621 41622 41623 41624 41625 41626 41627 41628 41629 41630 41631 41632 41633 41634 41635 41636 41637 41638 41639 41640 41641 41642 41643 |
# File 'lib/pago/v2026_04/models.rb', line 41612 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
41591 41592 41593 |
# File 'lib/pago/v2026_04/models.rb', line 41591 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
41575 41576 41577 |
# File 'lib/pago/v2026_04/models.rb', line 41575 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
41571 41572 41573 |
# File 'lib/pago/v2026_04/models.rb', line 41571 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
41579 41580 41581 |
# File 'lib/pago/v2026_04/models.rb', line 41579 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
41587 41588 41589 |
# File 'lib/pago/v2026_04/models.rb', line 41587 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
41559 41560 41561 |
# File 'lib/pago/v2026_04/models.rb', line 41559 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
41599 41600 41601 |
# File 'lib/pago/v2026_04/models.rb', line 41599 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
41583 41584 41585 |
# File 'lib/pago/v2026_04/models.rb', line 41583 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionReactivatedMetadata (readonly)
41610 41611 41612 |
# File 'lib/pago/v2026_04/models.rb', line 41610 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
41607 41608 41609 |
# File 'lib/pago/v2026_04/models.rb', line 41607 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
41567 41568 41569 |
# File 'lib/pago/v2026_04/models.rb', line 41567 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
41595 41596 41597 |
# File 'lib/pago/v2026_04/models.rb', line 41595 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
41603 41604 41605 |
# File 'lib/pago/v2026_04/models.rb', line 41603 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
41563 41564 41565 |
# File 'lib/pago/v2026_04/models.rb', line 41563 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionReactivatedEvent?
41647 41648 41649 41650 41651 41652 41653 41654 41655 41656 41657 41658 41659 41660 41661 41662 41663 41664 41665 41666 41667 41668 41669 41670 41671 |
# File 'lib/pago/v2026_04/models.rb', line 41647 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionReactivatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |