Class: Pago::V2026_04::Models::SubscriptionResumedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a paused subscription is resumed.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionResumedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionResumedEvent
constructor
A new instance of SubscriptionResumedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionResumedEvent
Returns a new instance of SubscriptionResumedEvent.
41849 41850 41851 41852 41853 41854 41855 41856 41857 41858 41859 41860 41861 41862 41863 41864 41865 41866 41867 41868 41869 41870 41871 41872 41873 41874 41875 41876 41877 41878 41879 41880 |
# File 'lib/pago/v2026_04/models.rb', line 41849 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
41828 41829 41830 |
# File 'lib/pago/v2026_04/models.rb', line 41828 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
41812 41813 41814 |
# File 'lib/pago/v2026_04/models.rb', line 41812 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
41808 41809 41810 |
# File 'lib/pago/v2026_04/models.rb', line 41808 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
41816 41817 41818 |
# File 'lib/pago/v2026_04/models.rb', line 41816 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
41824 41825 41826 |
# File 'lib/pago/v2026_04/models.rb', line 41824 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
41796 41797 41798 |
# File 'lib/pago/v2026_04/models.rb', line 41796 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
41836 41837 41838 |
# File 'lib/pago/v2026_04/models.rb', line 41836 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
41820 41821 41822 |
# File 'lib/pago/v2026_04/models.rb', line 41820 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionResumedMetadata (readonly)
41847 41848 41849 |
# File 'lib/pago/v2026_04/models.rb', line 41847 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
41844 41845 41846 |
# File 'lib/pago/v2026_04/models.rb', line 41844 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
41804 41805 41806 |
# File 'lib/pago/v2026_04/models.rb', line 41804 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
41832 41833 41834 |
# File 'lib/pago/v2026_04/models.rb', line 41832 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
41840 41841 41842 |
# File 'lib/pago/v2026_04/models.rb', line 41840 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
41800 41801 41802 |
# File 'lib/pago/v2026_04/models.rb', line 41800 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionResumedEvent?
41884 41885 41886 41887 41888 41889 41890 41891 41892 41893 41894 41895 41896 41897 41898 41899 41900 41901 41902 41903 41904 41905 41906 41907 41908 |
# File 'lib/pago/v2026_04/models.rb', line 41884 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionResumedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |