Class: Pago::V2026_04::Models::SubscriptionSeatsUpdatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a the seats on a subscription is changed.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionSeatsUpdatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionSeatsUpdatedEvent
constructor
A new instance of SubscriptionSeatsUpdatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionSeatsUpdatedEvent
Returns a new instance of SubscriptionSeatsUpdatedEvent.
42330 42331 42332 42333 42334 42335 42336 42337 42338 42339 42340 42341 42342 42343 42344 42345 42346 42347 42348 42349 42350 42351 42352 42353 42354 42355 42356 42357 42358 42359 42360 42361 |
# File 'lib/pago/v2026_04/models.rb', line 42330 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
42309 42310 42311 |
# File 'lib/pago/v2026_04/models.rb', line 42309 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
42293 42294 42295 |
# File 'lib/pago/v2026_04/models.rb', line 42293 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
42289 42290 42291 |
# File 'lib/pago/v2026_04/models.rb', line 42289 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
42297 42298 42299 |
# File 'lib/pago/v2026_04/models.rb', line 42297 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
42305 42306 42307 |
# File 'lib/pago/v2026_04/models.rb', line 42305 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
42277 42278 42279 |
# File 'lib/pago/v2026_04/models.rb', line 42277 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
42317 42318 42319 |
# File 'lib/pago/v2026_04/models.rb', line 42317 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
42301 42302 42303 |
# File 'lib/pago/v2026_04/models.rb', line 42301 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionSeatsUpdatedMetadata (readonly)
42328 42329 42330 |
# File 'lib/pago/v2026_04/models.rb', line 42328 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
42325 42326 42327 |
# File 'lib/pago/v2026_04/models.rb', line 42325 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
42285 42286 42287 |
# File 'lib/pago/v2026_04/models.rb', line 42285 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
42313 42314 42315 |
# File 'lib/pago/v2026_04/models.rb', line 42313 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
42321 42322 42323 |
# File 'lib/pago/v2026_04/models.rb', line 42321 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
42281 42282 42283 |
# File 'lib/pago/v2026_04/models.rb', line 42281 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionSeatsUpdatedEvent?
42365 42366 42367 42368 42369 42370 42371 42372 42373 42374 42375 42376 42377 42378 42379 42380 42381 42382 42383 42384 42385 42386 42387 42388 42389 |
# File 'lib/pago/v2026_04/models.rb', line 42365 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionSeatsUpdatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |