Class: Pago::V2026_04::Models::SubscriptionUncanceledEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a subscription cancellation is reversed.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionUncanceledMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionUncanceledEvent
constructor
A new instance of SubscriptionUncanceledEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionUncanceledEvent
Returns a new instance of SubscriptionUncanceledEvent.
42520 42521 42522 42523 42524 42525 42526 42527 42528 42529 42530 42531 42532 42533 42534 42535 42536 42537 42538 42539 42540 42541 42542 42543 42544 42545 42546 42547 42548 42549 42550 42551 |
# File 'lib/pago/v2026_04/models.rb', line 42520 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
42499 42500 42501 |
# File 'lib/pago/v2026_04/models.rb', line 42499 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
42483 42484 42485 |
# File 'lib/pago/v2026_04/models.rb', line 42483 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
42479 42480 42481 |
# File 'lib/pago/v2026_04/models.rb', line 42479 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
42487 42488 42489 |
# File 'lib/pago/v2026_04/models.rb', line 42487 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
42495 42496 42497 |
# File 'lib/pago/v2026_04/models.rb', line 42495 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
42467 42468 42469 |
# File 'lib/pago/v2026_04/models.rb', line 42467 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
42507 42508 42509 |
# File 'lib/pago/v2026_04/models.rb', line 42507 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
42491 42492 42493 |
# File 'lib/pago/v2026_04/models.rb', line 42491 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionUncanceledMetadata (readonly)
42518 42519 42520 |
# File 'lib/pago/v2026_04/models.rb', line 42518 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
42515 42516 42517 |
# File 'lib/pago/v2026_04/models.rb', line 42515 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
42475 42476 42477 |
# File 'lib/pago/v2026_04/models.rb', line 42475 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
42503 42504 42505 |
# File 'lib/pago/v2026_04/models.rb', line 42503 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
42511 42512 42513 |
# File 'lib/pago/v2026_04/models.rb', line 42511 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
42471 42472 42473 |
# File 'lib/pago/v2026_04/models.rb', line 42471 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionUncanceledEvent?
42555 42556 42557 42558 42559 42560 42561 42562 42563 42564 42565 42566 42567 42568 42569 42570 42571 42572 42573 42574 42575 42576 42577 42578 42579 |
# File 'lib/pago/v2026_04/models.rb', line 42555 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionUncanceledMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |