Class: Pago::V2026_04::Models::SubscriptionUpdateClearedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a pending subscription update is cleared without being applied.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionUpdateClearedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionUpdateClearedEvent
constructor
A new instance of SubscriptionUpdateClearedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionUpdateClearedEvent
Returns a new instance of SubscriptionUpdateClearedEvent.
42849 42850 42851 42852 42853 42854 42855 42856 42857 42858 42859 42860 42861 42862 42863 42864 42865 42866 42867 42868 42869 42870 42871 42872 42873 42874 42875 42876 42877 42878 42879 42880 |
# File 'lib/pago/v2026_04/models.rb', line 42849 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
42828 42829 42830 |
# File 'lib/pago/v2026_04/models.rb', line 42828 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
42812 42813 42814 |
# File 'lib/pago/v2026_04/models.rb', line 42812 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
42808 42809 42810 |
# File 'lib/pago/v2026_04/models.rb', line 42808 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
42816 42817 42818 |
# File 'lib/pago/v2026_04/models.rb', line 42816 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
42824 42825 42826 |
# File 'lib/pago/v2026_04/models.rb', line 42824 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
42796 42797 42798 |
# File 'lib/pago/v2026_04/models.rb', line 42796 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
42836 42837 42838 |
# File 'lib/pago/v2026_04/models.rb', line 42836 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
42820 42821 42822 |
# File 'lib/pago/v2026_04/models.rb', line 42820 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionUpdateClearedMetadata (readonly)
42847 42848 42849 |
# File 'lib/pago/v2026_04/models.rb', line 42847 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
42844 42845 42846 |
# File 'lib/pago/v2026_04/models.rb', line 42844 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
42804 42805 42806 |
# File 'lib/pago/v2026_04/models.rb', line 42804 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
42832 42833 42834 |
# File 'lib/pago/v2026_04/models.rb', line 42832 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
42840 42841 42842 |
# File 'lib/pago/v2026_04/models.rb', line 42840 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
42800 42801 42802 |
# File 'lib/pago/v2026_04/models.rb', line 42800 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionUpdateClearedEvent?
42884 42885 42886 42887 42888 42889 42890 42891 42892 42893 42894 42895 42896 42897 42898 42899 42900 42901 42902 42903 42904 42905 42906 42907 42908 |
# File 'lib/pago/v2026_04/models.rb', line 42884 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionUpdateClearedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |