Class: Pago::V2026_04::Models::SubscriptionUpdatedEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event created by Pago when a subscription is updated.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", source: "source", name: "name", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "source", "name", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::SubscriptionUpdatedMetadata readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionUpdatedEvent
constructor
A new instance of SubscriptionUpdatedEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata:) ⇒ SubscriptionUpdatedEvent
Returns a new instance of SubscriptionUpdatedEvent.
43059 43060 43061 43062 43063 43064 43065 43066 43067 43068 43069 43070 43071 43072 43073 43074 43075 43076 43077 43078 43079 43080 43081 43082 43083 43084 43085 43086 43087 43088 43089 43090 |
# File 'lib/pago/v2026_04/models.rb', line 43059 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, source:, name:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:source, source) assign(:name, name) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
43038 43039 43040 |
# File 'lib/pago/v2026_04/models.rb', line 43038 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
43022 43023 43024 |
# File 'lib/pago/v2026_04/models.rb', line 43022 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
43018 43019 43020 |
# File 'lib/pago/v2026_04/models.rb', line 43018 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
43026 43027 43028 |
# File 'lib/pago/v2026_04/models.rb', line 43026 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
43034 43035 43036 |
# File 'lib/pago/v2026_04/models.rb', line 43034 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
43006 43007 43008 |
# File 'lib/pago/v2026_04/models.rb', line 43006 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
43046 43047 43048 |
# File 'lib/pago/v2026_04/models.rb', line 43046 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
43030 43031 43032 |
# File 'lib/pago/v2026_04/models.rb', line 43030 def member_id @member_id end |
#metadata ⇒ Models::SubscriptionUpdatedMetadata (readonly)
43057 43058 43059 |
# File 'lib/pago/v2026_04/models.rb', line 43057 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
43054 43055 43056 |
# File 'lib/pago/v2026_04/models.rb', line 43054 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
43014 43015 43016 |
# File 'lib/pago/v2026_04/models.rb', line 43014 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
43042 43043 43044 |
# File 'lib/pago/v2026_04/models.rb', line 43042 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
43050 43051 43052 |
# File 'lib/pago/v2026_04/models.rb', line 43050 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
43010 43011 43012 |
# File 'lib/pago/v2026_04/models.rb', line 43010 def @timestamp end |
Class Method Details
.from_json(data) ⇒ SubscriptionUpdatedEvent?
43094 43095 43096 43097 43098 43099 43100 43101 43102 43103 43104 43105 43106 43107 43108 43109 43110 43111 43112 43113 43114 43115 43116 43117 43118 |
# File 'lib/pago/v2026_04/models.rb', line 43094 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::SubscriptionUpdatedMetadata.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |