Class: Pago::V2026_04::Models::UserEvent
- Defined in:
- lib/pago/v2026_04/models.rb,
sig/pago/v2026_04/generated.rbs
Overview
An event you created through the ingestion API.
Constant Summary collapse
- JSON_KEYS =
{ id: "id", timestamp: "timestamp", organization_id: "organization_id", customer_id: "customer_id", customer: "customer", external_customer_id: "external_customer_id", member_id: "member_id", external_member_id: "external_member_id", child_count: "child_count", parent_id: "parent_id", label: "label", name: "name", source: "source", metadata: "metadata" }.freeze
- REQUIRED_KEYS =
["id", "timestamp", "organization_id", "customer_id", "customer", "external_customer_id", "label", "name", "source", "metadata"].freeze
Instance Attribute Summary collapse
-
#child_count ⇒ Integer
readonly
Number of direct child events linked to this event.
-
#customer ⇒ Object?
readonly
The customer associated with the event.
-
#customer_id ⇒ String?
readonly
ID of the customer in your Pago organization associated with the event.
-
#external_customer_id ⇒ String?
readonly
ID of the customer in your system associated with the event.
-
#external_member_id ⇒ String?
readonly
ID of the member in your system within the customer's organization who performed the action inside B2B.
-
#id ⇒ String
readonly
The ID of the object.
-
#label ⇒ String
readonly
Human readable label of the event type.
-
#member_id ⇒ String?
readonly
ID of the member within the customer's organization who performed the action inside B2B.
- #metadata ⇒ Models::EventMetadataOutput readonly
-
#name ⇒ String
readonly
The name of the event.
-
#organization_id ⇒ String
readonly
The ID of the organization owning the event.
-
#parent_id ⇒ String?
readonly
The ID of the parent event.
-
#source ⇒ String
readonly
The source of the event.
-
#timestamp ⇒ String
readonly
The timestamp of the event.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, name:, source:, metadata:) ⇒ UserEvent
constructor
A new instance of UserEvent.
Methods inherited from Model
#==, #[], #field_set?, #hash, #inspect, json_keys, required_json_keys, #to_json, #to_json_hash, wrap_raw
Constructor Details
#initialize(id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, name:, source:, metadata:) ⇒ UserEvent
Returns a new instance of UserEvent.
43677 43678 43679 43680 43681 43682 43683 43684 43685 43686 43687 43688 43689 43690 43691 43692 43693 43694 43695 43696 43697 43698 43699 43700 43701 43702 43703 43704 43705 43706 43707 43708 |
# File 'lib/pago/v2026_04/models.rb', line 43677 def initialize( id:, timestamp:, organization_id:, customer_id:, customer:, external_customer_id:, member_id: ::Pago::UNSET, external_member_id: ::Pago::UNSET, child_count: ::Pago::UNSET, parent_id: ::Pago::UNSET, label:, name:, source:, metadata: ) super() assign(:id, id) assign(:timestamp, ) assign(:organization_id, organization_id) assign(:customer_id, customer_id) assign(:customer, customer) assign(:external_customer_id, external_customer_id) assign(:member_id, member_id) assign(:external_member_id, external_member_id) assign(:child_count, child_count) assign(:parent_id, parent_id) assign(:label, label) assign(:name, name) assign(:source, source) assign(:metadata, ) end |
Instance Attribute Details
#child_count ⇒ Integer (readonly)
Number of direct child events linked to this event.
43656 43657 43658 |
# File 'lib/pago/v2026_04/models.rb', line 43656 def child_count @child_count end |
#customer ⇒ Object? (readonly)
The customer associated with the event.
43640 43641 43642 |
# File 'lib/pago/v2026_04/models.rb', line 43640 def customer @customer end |
#customer_id ⇒ String? (readonly)
ID of the customer in your Pago organization associated with the event.
43636 43637 43638 |
# File 'lib/pago/v2026_04/models.rb', line 43636 def customer_id @customer_id end |
#external_customer_id ⇒ String? (readonly)
ID of the customer in your system associated with the event.
43644 43645 43646 |
# File 'lib/pago/v2026_04/models.rb', line 43644 def external_customer_id @external_customer_id end |
#external_member_id ⇒ String? (readonly)
ID of the member in your system within the customer's organization who performed the action inside B2B.
43652 43653 43654 |
# File 'lib/pago/v2026_04/models.rb', line 43652 def external_member_id @external_member_id end |
#id ⇒ String (readonly)
The ID of the object.
43624 43625 43626 |
# File 'lib/pago/v2026_04/models.rb', line 43624 def id @id end |
#label ⇒ String (readonly)
Human readable label of the event type.
43664 43665 43666 |
# File 'lib/pago/v2026_04/models.rb', line 43664 def label @label end |
#member_id ⇒ String? (readonly)
ID of the member within the customer's organization who performed the action inside B2B.
43648 43649 43650 |
# File 'lib/pago/v2026_04/models.rb', line 43648 def member_id @member_id end |
#metadata ⇒ Models::EventMetadataOutput (readonly)
43675 43676 43677 |
# File 'lib/pago/v2026_04/models.rb', line 43675 def @metadata end |
#name ⇒ String (readonly)
The name of the event.
43668 43669 43670 |
# File 'lib/pago/v2026_04/models.rb', line 43668 def name @name end |
#organization_id ⇒ String (readonly)
The ID of the organization owning the event.
43632 43633 43634 |
# File 'lib/pago/v2026_04/models.rb', line 43632 def organization_id @organization_id end |
#parent_id ⇒ String? (readonly)
The ID of the parent event.
43660 43661 43662 |
# File 'lib/pago/v2026_04/models.rb', line 43660 def parent_id @parent_id end |
#source ⇒ String (readonly)
The source of the event. system events are created by Pago. user events are the one you create through our ingestion API.
43672 43673 43674 |
# File 'lib/pago/v2026_04/models.rb', line 43672 def source @source end |
#timestamp ⇒ String (readonly)
The timestamp of the event.
43628 43629 43630 |
# File 'lib/pago/v2026_04/models.rb', line 43628 def @timestamp end |
Class Method Details
.from_json(data) ⇒ UserEvent?
43712 43713 43714 43715 43716 43717 43718 43719 43720 43721 43722 43723 43724 43725 43726 43727 43728 43729 43730 43731 43732 43733 43734 43735 43736 |
# File 'lib/pago/v2026_04/models.rb', line 43712 def self.from_json(data) data = ::JSON.parse(data) if data.is_a?(String) data = ::Pago::Serde.object(data) return nil if data.nil? wrap_raw( new( id: (data.key?("id") ? data["id"] : ::Pago::UNSET), timestamp: (data.key?("timestamp") ? data["timestamp"] : ::Pago::UNSET), organization_id: (data.key?("organization_id") ? data["organization_id"] : ::Pago::UNSET), customer_id: (data.key?("customer_id") ? data["customer_id"] : ::Pago::UNSET), customer: (data.key?("customer") ? Unions::Customer.from_json(data["customer"]) : ::Pago::UNSET), external_customer_id: (data.key?("external_customer_id") ? data["external_customer_id"] : ::Pago::UNSET), member_id: (data.key?("member_id") ? data["member_id"] : ::Pago::UNSET), external_member_id: (data.key?("external_member_id") ? data["external_member_id"] : ::Pago::UNSET), child_count: (data.key?("child_count") ? data["child_count"] : ::Pago::UNSET), parent_id: (data.key?("parent_id") ? data["parent_id"] : ::Pago::UNSET), label: (data.key?("label") ? data["label"] : ::Pago::UNSET), name: (data.key?("name") ? data["name"] : ::Pago::UNSET), source: (data.key?("source") ? data["source"] : ::Pago::UNSET), metadata: (data.key?("metadata") ? Models::EventMetadataOutput.from_json(data["metadata"]) : ::Pago::UNSET) ), data ) end |